<?php
return ['x-generator'=>'GlotPress/4.0.3','translation-revision-date'=>'2026-06-01 13:34:03+0000','plural-forms'=>'nplurals=2; plural=n != 1;','project-id-version'=>'Plugins - Jetpack &#8211; WP Security, Backup, Speed, &amp; Growth - Stable (latest release)','language'=>'en_GB','messages'=>['block descriptionControls the order of Jetpack Search results.'=>'Controls the order of Jetpack Search results.','block titleSort Control'=>'Sort Control','block descriptionDisplays Jetpack Search results.'=>'Displays Jetpack Search results.','block titleSearch Results'=>'Search Results','block descriptionText input that drives Jetpack Search results.'=>'Text input that drives Jetpack Search results.','block titleSearch Input'=>'Search Input','block descriptionMessage shown when a Jetpack Search request fails.'=>'Message shown when a Jetpack Search request fails.','block titleSearch Error'=>'Search Error','block descriptionDisplays the Jetpack Search results count.'=>'Displays the Jetpack Search results count.','block titleResults Count'=>'Results Count','block descriptionMessage shown when Jetpack Search returns no results.'=>'Message shown when Jetpack Search returns no results.','block titleNo Results'=>'No Results','block descriptionLoads the next page of Jetpack Search results.'=>'Loads the next page of Jetpack Search results.','block titleLoad More'=>'Load More','block titleFilter Popover'=>'Filter Popover','block descriptionDate filter for Jetpack Search. Group results into yearly or monthly buckets so visitors can scope a search to a single time window.'=>'Date filter for Jetpack Search. Group results into yearly or monthly buckets so visitors can scope a search to a single time window.','block titleDate Filter'=>'Date Filter','block keywordfilters'=>'filters','block keywordfilter'=>'filter','block keywordsearch'=>'search','block descriptionContainer for a stack of Jetpack Search filter blocks. Pre-populated with the most common filters; rearrange, remove, or add more from the inserter.'=>'Container for a stack of Jetpack Search filter blocks. Pre-populated with the most common filters; rearrange, remove, or add more from the inserter.','block titleFilters'=>'Filters','block descriptionPills showing the currently selected Jetpack Search filters.'=>'Pills showing the currently selected Jetpack Search filters.','block titleActive Filters'=>'Active Filters','Tracking/segmentation identifier for this authorize URL request'=>'Tracking/segmentation identifier for this authorise URL request','Site URL'=>'Site URL','Module DescriptionOptimize titles, meta descriptions, and social previews for better search results.'=>'Optimise titles, meta descriptions, and social previews for better search results.','You aren\'t authorized to do that.'=>'You aren\'t authorised to do that.','Optimizes lazy-loaded images by dynamically serving perfectly sized images for each device.'=>'Optimises lazy-loaded images by dynamically serving perfectly sized images for each device.','Optimize your titles for better performance'=>'Optimise your titles for better performance','Add Subscribe block to the navigation.'=>'Add Subscribe block to the navigation.','Deprecated Jetpack Stats Experience'=>'Deprecated Jetpack Stats Experience','Sorry, you are not allowed to view admin color on this site.'=>'Sorry, you are not allowed to view admin colour on this site.','<p>Status: <span style="color:%1$s;">%2$s</span></p><pre>%3$s</pre>'=>'<p>Status: <span style="color:%1$s;">%2$s</span></p><pre>%3$s</pre>','Product rating'=>'Product rating','Unauthorized'=>'Unauthorised','Open overlay from filter links'=>'Open overlay from filter links','Open overlay when filters are used outside the Jetpack Sidebar'=>'Open overlay when filters are used outside the Jetpack Sidebar','Filtering Search Overlay'=>'Filtering Search Overlay','<p>It’s essential to regenerate Critical CSS to optimize your site speed whenever your HTML or CSS structure changes. Being on top of this can be tedious and time-consuming.</p>
								 <p>Boost’s cloud service can automatically detect when your site needs the Critical CSS regenerated, and perform this function behind the scenes without requiring you to monitor it manually.</p>'=>'<p>It’s essential to regenerate Critical CSS to optimise your site speed whenever your HTML or CSS structure changes. Being on top of this can be tedious and time-consuming.</p>
								 <p>Boost’s cloud service can automatically detect when your site needs the Critical CSS regenerated, and perform this function behind the scenes without requiring you to monitor it manually.</p>','<p>To enhance the speed of your site, with this plan you will need to optimize CSS by using the Manual Critical CSS generation feature whenever you:</p>
								<ul>
									<li>Make theme changes.</li>
									<li>Write a new post/page.</li>
									<li>Edit a post/page.</li>
									<li>Activate, deactivate, or update plugins that impact your site layout or HTML structure.</li>
									<li>Change settings of plugins that impact your site layout or HTML structure.</li>
									<li>Upgrade your WordPress version if the new release includes core CSS changes.</li>
								</ul>'=>'<p>To enhance the speed of your site, with this plan you will need to optimise CSS by using the Manual Critical CSS generation feature whenever you:</p>
								<ul>
									<li>Make theme changes.</li>
									<li>Write a new post/page.</li>
									<li>Edit a post/page.</li>
									<li>Activate, deactivate, or update plugins that impact your site layout or HTML structure.</li>
									<li>Change settings of plugins that impact your site layout or HTML structure.</li>
									<li>Upgrade your WordPress version if the new release includes core CSS changes.</li>
								</ul>','Show post date'=>'Show post date','Jetpack Stats'=>'Jetpack Stats','The caption of the video.'=>'The caption of the video.','Could not fetch site information from the service'=>'Could not fetch site information from the service','Select a file to upload.'=>'Select a file to upload.','Included'=>'Included','Whether the post was ever published.'=>'Whether the post was ever published.','Manage Email'=>'Manage Email','Manage Domain'=>'Manage Domain','The attachment id of the poster image.'=>'The attachment id of the poster image.','Whether the time is in milliseconds or seconds.'=>'Whether the time is in milliseconds or seconds.','The time in the video to use as the poster frame.'=>'The time in the video to use as the poster frame.','Leave a comment'=>'Leave a comment','block descriptionEmbed a video from your media library or upload a new one with VideoPress.'=>'Embed a video from your media library or upload a new one with VideoPress.','block titleVideoPress'=>'VideoPress','Open when user submits the form (recommended)'=>'Open when user submits the form (recommended)','Backup Product DisclaimerLearn more'=>'Learn more','Backup Product Disclaimer* Subject to your usage and storage limit.'=>'* Subject to your usage and storage limit.','Tap to open embedded document in %s.'=>'Tap to open embedded document in %s.','Google Slides'=>'Google Slides','Google Sheets'=>'Google Sheets','Google Docs'=>'Google Docs','Google Document Embed'=>'Google Document Embed','* Subject to your usage and storage limit.'=>'* Subject to your usage and storage limit.','Jetpack Social connection %d could not be disconnected.'=>'Jetpack Social connection %d could not be disconnected.','Jetpack Social connection %d has been disconnected.'=>'Jetpack Social connection %d has been disconnected.','Jetpack Social connection %d could not be disconnected'=>'Jetpack Social connection %d could not be disconnected','You\'re about to delete all Jetpack Social connections.'=>'You\'re about to delete all Jetpack Social connections.','The Jetpack Social module is not loaded.'=>'The Jetpack Social module is not loaded.','The Jetpack Social module is not active.'=>'The Jetpack Social module is not active.','Jetpack Modules List'=>'Jetpack Modules List','The Jetpack Firewall is a web application firewall designed to protect your WordPress site from malicious requests.'=>'The Jetpack Firewall is a web application firewall designed to protect your WordPress site from malicious requests.','Integrations'=>'Integrations','Module TagWAF'=>'WAF','indicates movement (up or down)UP'=>'UP','Openverse'=>'Openverse','There are no popular posts to display. Instead, your visitors will see a list of your recent posts below. <a href="%s" target="_blank">Want more traffic?</a>'=>'There are no popular posts to display. Instead, your visitors will see a list of your recent posts below. <a href="%s" target="_blank">Want more traffic?</a>','Help your visitors find exactly what they are looking for, fast'=>'Help your visitors find exactly what they are looking for, fast','Jetpack Blocks disabled.'=>'Jetpack Blocks disabled.','Search termsblocks, block, gutenberg'=>'blocks, block, gutenberg','The upload handler cannot upload files'=>'The upload handler cannot upload files','View options to switch betweenView'=>'View','Default view'=>'Default view','Our WordPress.com redesign for a better experience.'=>'Our WordPress.com redesign for a better experience.','Classic view'=>'Classic view','The classic WP-Admin WordPress interface.'=>'The classic WP-Admin WordPress interface.','My Jetpack dashboard'=>'My Jetpack dashboard','Could not obtain a VideoPress upload JWT. Please try again later.'=>'Could not obtain a VideoPress upload JWT. Please try again later.','Could not obtain a VideoPress upload JWT. Please try again later. (empty upload token)'=>'Could not obtain a VideoPress upload JWT. Please try again later. (empty upload token)','Module TagFonts'=>'Fonts','A selection of Google fonts for block enabled themes.  This feature is still being developed.'=>'A selection of Google fonts for block enabled themes.  This feature is still being developed.','Module NameGoogle Fonts (Beta)'=>'Google Fonts (Beta)','Type your email…'=>'Type your email…','compact'=>'compact','Activation failed. Plugin is not installed'=>'Activation failed. Plugin is not installed','Security Product FeatureComment & form spam protection'=>'Comment and form spam protection','Security Product FeatureOne-click fixes for most threats'=>'One-click fixes for most threats','Security Product FeatureAutomated real-time malware scan'=>'Automated real-time malware scan','Security Product FeatureReal-time cloud backups with 10GB storage'=>'Real-time cloud backups with 10GB storage','Infinitely customizable with integrations and extensions'=>'Infinitely customisable with integrations and extensions','Fully integrated with WordPress & WooCommerce'=>'Fully integrated with WordPress and WooCommerce','Manage billing and create invoices'=>'Manage billing and create invoices','Manage unlimited contacts'=>'Manage unlimited contacts','VideoPress Video Player'=>'VideoPress Video Player','Spelling correction'=>'Spelling correction','Powerful filtering'=>'Powerful filtering','Instant search and indexing'=>'Instant search and indexing','Standalone free plugin for those focused on speed'=>'Standalone free plugin for those focused on speed','Enable improvements in one click'=>'Enable improvements in one click','Check your site performance'=>'Check your site performance','Error activating Jetpack module'=>'Error activating Jetpack module','Error activating Jetpack plugin'=>'Error activating Jetpack plugin','Unable to fetch the products list from WordPress.com'=>'Unable to fetch the products list from WordPress.com','Method \'%s\' not implemented. Must be overridden in subclass.'=>'Method \'%s\' not implemented. Must be overridden in subclass.','Your plan does not support Instant Search.'=>'Your plan does not support Instant Search.','Product slug'=>'Product slug','Production action to execute'=>'Production action to execute','Basic tools for a successful site'=>'Basic tools for a successful site','The product argument must be a string.'=>'The product argument must be a string.','The required "nonce" parameter is missing.'=>'The required "nonce" parameter is missing.','Your password is too weak: Looks like you are including easy to guess information about yourself. Try something a little more unique.'=>'Your password is too weak: looks like you are including easy to guess information about yourself. Try something a little more unique.','Your plan does not support Jetpack Search.'=>'Your plan does not support Jetpack Search.','Search module needs to be activated before enabling instant search.'=>'Search module needs to be activated before enabling instant search.','Some settings ( %s ) not updated.'=>'Some settings (%s) not updated.','The arguments passed in are invalid.'=>'The arguments passed in are invalid.','Sync has been aborted because the IXR client is missing.'=>'Sync has been aborted because the IXR client is missing.','Data Modules that should be included in Full Sync'=>'Data Modules that should be included in Full Sync','User IDs to include in Full Sync or "initial"'=>'User IDs to include in Full Sync or "initial"','Post IDs to include in Full Sync'=>'Post IDs to include in Full Sync','Comment IDs to include in Full Sync'=>'Comment IDs to include in Full Sync','New Sync health status'=>'New Sync health status','Name of Sync module'=>'Name of Sync module','Object Type'=>'Object Type','Objects Identifiers'=>'Objects Identifiers','Name of Sync queue.'=>'Name of Sync queue.','Name of Sync module.'=>'Name of Sync module.','Size of batches'=>'Size of batches','If text fields should be converted to latin1 in checksum calculation.'=>'If text fields should be converted to latin1 in checksum calculation.','Column mappings'=>'Column mappings','Number of histogram buckets.'=>'Number of histogram buckets.','Start ID for the histogram'=>'Start ID for the histogram','End ID for the histogram'=>'End ID for the histogram','Strip non-ascii characters?'=>'Strip non-ASCII characters?','Shared Salt to use when generating checksum'=>'Shared Salt to use when generating checksum','Do we want the checksum or object ids.'=>'Do we want the checksum or object IDs?','No valid event name or type.'=>'No valid event name or type.','A header for the video allow download option areaDownload'=>'Download','Display download option and allow viewers to download this video'=>'Display download option and allow viewers to download this video','Subscribe to posts'=>'Subscribe to posts','RSS - Posts'=>'RSS – Posts','Subscribe to comments'=>'Subscribe to comments','RSS - Comments'=>'RSS – Comments','RSS feed'=>'RSS Feed','Should only range edges be returned'=>'Should only range edges be returned','Comma-separated list of additional fields that should be included in status.'=>'Comma-separated list of additional fields that should be included in status.','Every Jetpack site needs at least one connected admin for the features to work properly. Please connect to your WordPress.com account via the button below. Once you connect, you may refresh this page to see an option to change the connection owner.'=>'Every Jetpack site needs at least one connected admin for the features to work properly. Please connect to your WordPress.com account via the button below. Once you connect, you may refresh this page to see an option to change the connection owner.','<a href=\'%s\' target=\'_blank\' rel=\'noopener noreferrer\'>Learn more</a> about the connection owner and what will break if you do not have one.'=>'<a href=\'%s\' target=\'_blank\' rel=\'noopener noreferrer\'>Learn more</a> about the connection owner and what will break if you do not have one.','As always, feel free to <a href="%s" target="_blank" rel="noopener noreferrer">contact our support team</a> if you have any questions.'=>'As always, feel free to <a href="%s" target="_blank" rel="noopener noreferrer">contact our support team</a> if you have any questions.','Jetpack doesn\'t have a connected owner.'=>'Jetpack doesn\'t have a connected owner.','License attach request failed.'=>'Licence attach request failed.','Failed to attach your Jetpack license(s). Please try reconnecting Jetpack.'=>'Failed to attach your Jetpack licence(s). Please try reconnecting Jetpack.','The following Jetpack licenses are invalid, already in use, or revoked: %s'=>'The following Jetpack licences are invalid, already in use, or revoked: %s','Warning! You are about to delete the Jetpack connection owner (%s) for this site, which may cause some of your Jetpack features to stop working.'=>'Warning! You are about to delete the Jetpack connection owner (%s) for this site, which may cause some of your Jetpack features to stop working.','You can choose to transfer connection ownership to one of these already-connected admins:'=>'You can choose to transfer connection ownership to one of these already-connected admins:','Set new connection owner'=>'Set new connection owner','Important notice about your Jetpack connection:'=>'Important notice about your Jetpack connection:','Jetpack experienced an issue trying to save options (cannot_save_secrets). We suggest that you contact your hosting provider, and ask them for help checking that the options table is writable on your site.'=>'Jetpack experienced an issue trying to save options (cannot_save_secrets). We suggest that you contact your hosting provider, and ask them for help checking that the options table is writable on your site.','Invalid Registration State'=>'Invalid Registration State','You cannot call this method until Jetpack Config is configured'=>'You cannot call this method until Jetpack Config is configured','The request method is missing.'=>'The request method is missing.','Set to false will trigger the site to disconnect.'=>'Set to false will trigger the site to disconnect.','The isActive argument should be set to false.'=>'The isActive argument should be set to false.','Indicates where the registration action was triggered for tracking/segmentation purposes'=>'Indicates where the registration action was triggered for tracking/segmentation purposes','URI of the admin page where the user should be redirected after connection flow'=>'URI of the admin page where the user should be redirected after connection flow','Indicates from what plugin the request is coming from'=>'Indicates from what plugin the request is coming','New user token'=>'New user token','Is connection owner'=>'Is connection owner','New owner'=>'New owner','Invalid user token is provided'=>'Invalid user token is provided','Invalid user id is provided'=>'Invalid user ID is provided','Site is not connected'=>'Site is not connected','Failed to disconnect the site as it appears already disconnected.'=>'Failed to disconnect the site as it appears already disconnected.','The required "%s" parameter is malformed.'=>'The required "%s" parameter is malformed.','Verification secrets not found'=>'Verification secrets not found','Verification took too long'=>'Verification took too long','Verification secrets are empty'=>'Verification secrets are empty','Verification secrets are incomplete'=>'Verification secrets are incomplete','Secret mismatch'=>'Secret mismatch','No user tokens found'=>'No user tokens found','No primary user defined'=>'No primary user defined','No token for user %d'=>'No token for user %d','Token for user %d is malformed'=>'Token for user %d is malformed','Requesting user_id %1$d does not match token user_id %2$d'=>'Requesting user_id %1$d does not match token user_id %2$d','No blog token found'=>'No blog token found','Invalid token for user %d'=>'Invalid token for user %d','Invalid blog token'=>'Invalid blog token','Last heartbeat sent at: %s'=>'Last heartbeat sent at: %s','Unable to load class %1$s. Please add the package that contains it using composer and make sure you are requiring the Jetpack autoloader'=>'Unable to load class %1$s. Please add the package that contains it using Composer and make sure you are requiring the Jetpack autoloader','Blog is already registered'=>'Blog is already registered','Your connection with WordPress.com seems to be broken. If you\'re experiencing issues, please try reconnecting.'=>'Your connection with WordPress.com seems to be broken. If you\'re experiencing issues, please try reconnecting.','New owner is same as existing owner'=>'New owner is same as existing owner','Script "%s" depends on wp-i18n but does not specify "textdomain"'=>'Script "%s" depends on wp-i18n but does not specify "textdomain"','Textdomain aliases should be registered before the %1$s hook. This notice was triggered by the %2$s domain.'=>'Textdomain aliases should be registered before the %1$s hook. This notice was triggered by the %2$s domain.','base64 encoded Backup Helper Script body.'=>'base64 encoded Backup Helper Script body.','Path to Backup Helper Script'=>'Path to Backup Helper Script','Type of object to fetch from the database'=>'Type of object to fetch from the database','The object_type argument must be a non-empty string.'=>'The object_type argument must be a non-empty string.','The object_type argument should be one of %s'=>'The object_type argument should be one of %s','ID of the database object to fetch'=>'ID of the database object to fetch','One or more option names to include in the backup'=>'One or more option names to include in the backup','The name argument should be an option name or an array of option names'=>'The name argument should be an option name or an array of option names','You are not allowed to perform this action.'=>'You are not allowed to perform this action.','Author'=>'Author','Upgrade now'=>'Upgrade now','%s must be a non-negative integer.'=>'%s must be a non-negative integer.','Missing parameter "last_detached_count".'=>'Missing parameter "last_detached_count".','Backup Product Feature10GB of backup storage'=>'10GB of backup storage','There was an error installing Jetpack Backup. Please try again.'=>'There was an error installing Jetpack Backup. Please try again.','There was an error installing Jetpack Boost. Please try again.'=>'There was an error installing Jetpack Boost. Please try again.','Backup Product FeatureReal-time cloud backups'=>'Real-time cloud backups','Comprehensive site security, including Backup, Scan, and Anti-spam.'=>'Comprehensive site security, including Backup, Scan, and Anti-spam.','Security Tier 1 FeatureReal-time cloud backups with 10GB storage'=>'Real-time cloud backups with 10GB of storage','Return to main content.'=>'Return to main content.','Read footnote.'=>'Read footnote.','Engage your visitors with high-quality, ad-free videos built specifically for WordPress.'=>'Engage your visitors with high quality, ad-free videos built specifically for WordPress.','VideoPress Product FeatureUnlimited users'=>'Unlimited users','VideoPress Product FeatureBuilt into WordPress editor'=>'Built into the WordPress editor','VideoPress Product Feature1TB of storage'=>'1TB of storage','Display share menu and allow viewers to copy a link or embed this video'=>'Display share menu and allow viewers to copy a link or embed this video','Whether or not the Share Post feature is enabled.'=>'Whether or not the share post feature is enabled.','Security Daily Plan FeatureComment & form spam protection'=>'Comment and form spam protection','Array of external connection IDs to skip sharing.'=>'Array of external connection IDs to skip sharing.','The message to share.'=>'The message to share.','VideoPress uploads are not supported here. To upload to VideoPress, add your videos from the <a href="%s">Media Library</a> or the block editor using the Video block.'=>'VideoPress uploads are not supported here. To upload to VideoPress, add your videos from the <a href="%s">Media Library</a> or the block editor using the Video block.','Security Daily Plan FeatureOne-click fixes for most threats'=>'One-click fixes for most threats','Security Daily Plan FeatureAutomated real-time malware scan'=>'Automated real-time malware scan','Anti-Spam Product FeatureAdvanced stats'=>'Advanced stats','Anti-Spam Product FeatureBlock spam without CAPTCHAs'=>'Block spam without CAPTCHAs','Anti-Spam Product FeatureComment and form spam protection'=>'Comment and form spam protection','Save time and get better responses by automatically blocking spam from your comments and forms.'=>'Save time and get better responses by automatically blocking spam from your comments and forms.','Search Product FeatureSpelling correction'=>'Spelling correction','Search Product FeaturePowerful filtering'=>'Powerful filtering','Search Product FeatureInstant search and indexing'=>'Instant search and indexing','Help your site visitors find answers instantly so they keep reading and buying. Great for sites with a lot of content.'=>'Help your site visitors find answers instantly so they keep reading and buying. Great for sites with a lot of content.','Jetpack Site Search'=>'Jetpack Site Search','Scan Product FeatureInstant email notifications'=>'Instant email notifications','Scan Product FeatureOne-click fixes for most issues'=>'One-click fixes for most issues','Scan Product FeatureAutomated daily scanning'=>'Automated daily scanning','Automatic scanning and one-click fixes keep your site one step ahead of security threats and malware.'=>'Automatic scanning and one-click fixes keep your site one step ahead of security threats and malware.','Backup Product FeatureUnlimited backup storage'=>'Unlimited backup storage','Backup Product FeatureOne-click restores'=>'One-click restores','Backup Product FeatureAutomated daily backups (off-site)'=>'Automated daily backups (off-site)','Never lose a word, image, page, or time worrying about your site with automated backups & one-click restores.'=>'Never lose a word, image, page, or time worrying about your site with automated backups and one-click restores.','Jetpack VideoPress'=>'Jetpack VideoPress','High-quality, ad-free video built specifically for WordPress.'=>'High quality, ad-free video built specifically for WordPress.','Enhance your site with dozens of other features'=>'Enhance your site with dozens of other features','Get notifications if your site goes offline'=>'Get notifications if your site goes offline','Protect your site against bot attacks'=>'Protect your site against bot attacks','Speed up your site with optimized images'=>'Speed up your site with optimised images','Secure and speed up your site for free with Jetpack\'s powerful WordPress tools.'=>'Secure and speed up your site for free with Jetpack\'s powerful WordPress tools.','Loading…'=>'Loading…','Jetpack logo'=>'Jetpack logo','To specify a range, enter the low value and high value separated by a dash. Example: 12.12.12.1-12.12.12.100'=>'To specify a range, enter the low value and high value separated by a dash. Example: 12.12.12.1-12.12.12.100','Jetpack Logo'=>'Jetpack Logo','IPv4 and IPv6 are acceptable. Enter multiple IPs on separate lines.'=>'IPv4 and IPv6 are acceptable. Enter multiple IPs on separate lines.','Allow individual site administrators to manage their own connections (connect and disconnect) to WordPress.com'=>'Allow individual site administrators to manage their own connections (connect and disconnect) to WordPress.com','YouTube video'=>'YouTube video','Hulu no longer allows embedding content.'=>'Hulu no longer allows embedding content.','Collapse upgrade nudges'=>'Collapse upgrade nudges','Next quiz'=>'Next quiz','Previous quiz'=>'Previous quiz','CRM'=>'CRM','Install CRM'=>'Install CRM','Activate CRM'=>'Activate CRM','Boost'=>'Boost','Improve your site\'s performance and SEO in a few clicks with the free Jetpack Boost plugin.'=>'Improve your site\'s performance and SEO in a few clicks with the free Jetpack Boost plugin.','Install Boost'=>'Install Boost','Activate Boost'=>'Activate Boost','Help your site visitors instantly find what they\'re looking for so they read and buy more.'=>'Help your site visitors instantly find what they\'re looking for so they read and buy more.','Stay ahead of security threats with automated scanning and one-click fixes.'=>'Stay ahead of security threats with automated scanning and one-click fixes.','Comprehensive protection for your site, including Backup, Scan, and Anti-spam.'=>'Comprehensive protection for your site, including Backup, Scan, and Anti-spam.','Security, performance, and growth tools for %s'=>'Security, performance, and growth tools for %s','Performance and growth tools for %s'=>'Performance and growth tools for %s','Like or Reblog'=>'Like or Reblog','Sell more and get more leads with the free Jetpack CRM plugin built specifically for WordPress.'=>'Sell more and get more leads with the free Jetpack CRM plugin built specifically for WordPress.','No map preview available. Publish and refresh to see this widget.'=>'No map preview available. Publish and refresh to see this widget.','The media you are trying to update is not processed by VideoPress.'=>'The media you are trying to update is not processed by VideoPress.','WordPress.com users can change their profile’s email & website address in <a href="%1$s" target="_blank" rel="noopener noreferrer">WordPress.com Account settings.</a>'=>'WordPress.com users can change their profile’s email and website address in <a href="%1$s" target="_blank" rel="noopener noreferrer">WordPress.com Account settings.</a>','WordPress.com users can change their profile’s basic details ( i.e., First Name, Last Name, Display Name, About ) in <a href="%1$s" target="_blank" rel="noopener noreferrer">WordPress.com Profile settings.</a>'=>'WordPress.com users can change their profile’s basic details (ie First Name, Last Name, Display Name, About) in <a href="%1$s" target="_blank" rel="noopener noreferrer">WordPress.com Profile settings.</a>','This image has comments.'=>'This image has comments.','Toggle photo comments visibility'=>'Toggle photo comments visibility','Toggle photo metadata visibility'=>'Toggle photo metadata visibility','Purchase the %s plan to<br> activate CSS customization'=>'Purchase the %s plan to<br> activate CSS customisation','Preview: %s'=>'Preview: %s','Post title'=>'Post title','Filter options'=>'Filter options','Missing user info.'=>'Missing user info.','Missing attachment info.'=>'Missing attachment info.','No responses found'=>'No responses found','Search Responses'=>'Search Responses','Form Responses'=>'Form Responses','The content of your latest posts page is automatically generated and cannot be edited.'=>'The content of your latest posts page is automatically generated and cannot be edited.','There is nothing to display yet'=>'There is nothing to display yet','You do not need to pass a $content parameter anymore.'=>'You do not need to pass a $content parameter anymore.','Choose post types to exclude from search results. You must leave at least one post type unchecked.'=>'Choose post types to exclude from search results. You must leave at least one post type unchecked.','Additional CSS'=>'Additional CSS','We were unable to get your stats just now. Please reload this page to try again. If this error persists, please contact %1$s. In your report, please include the information below.'=>'We were unable to get your stats just now. Please reload this page to try again. If this error persists, please contact %1$s. In your report, please include the information below.','Product (for WooCommerce stores)'=>'Product (for WooCommerce stores)','Expanded (shows images)'=>'Expanded (shows images)','Updates are already in progress.'=>'Updates are already in progress.','User %s could not be disconnected.'=>'User %s could not be disconnected.','User %s could not be disconnected because it is the connection owner! If you want to disconnect in anyway, use the --force parameter.'=>'User %s could not be disconnected because it is the connection owner! If you want to disconnect in anyway, use the --force parameter.','User %s could not be disconnected because it is not connected!'=>'User %s could not be disconnected because it is not connected!','Sorry, you are not allowed to delete this transient.'=>'Sorry, you are not allowed to delete this transient.','The name of the transient to delete.'=>'The name of the transient to delete.','Facebook Domain Verification'=>'Facebook Domain Verification','Security, performance, and marketing tools made by WordPress experts. Jetpack keeps your site protected so you can focus on more important things.'=>'Security, performance, and marketing tools made by WordPress experts. Jetpack keeps your site protected so you can focus on more important things.','Jetpack is running without a connected user. No master user to check.'=>'Jetpack is running without a connected user. No master user to check.','Not supported by current plan'=>'Not supported by current plan','Requires a connected WordPress.com account'=>'Requires a connected WordPress.com account','Jetpack is not connected'=>'Jetpack is not connected','Offline mode'=>'Offline mode','Requires WooCommerce 3+ plugin'=>'Requires WooCommerce 3+ plugin','Blog token validation failed.'=>'Blog token validation failed.','Missing token for the connection owner.'=>'Missing token for the connection owner.','Could not set this license key. Please try again.'=>'Could not set this licence key. Please try again.','SEO page title structures.'=>'SEO page title structures.','Front page meta description.'=>'Front page meta description.','Price: high to low'=>'Price: high to low','Price: low to high'=>'Price: low to high','Log in'=>'Log in','Country code'=>'Country code','In order to use this widget you need to %1$scomplete your Jetpack connection%2$s by authorizing your user.'=>'In order to use this widget, you need to %1$scomplete your Jetpack connection%2$s by authorising your user.','The UTC publish date and time of the episode'=>'The UTC publish date and time of the episode','The value used for that option, the episode GUID'=>'The value used for that option, the episode GUID','The display label of the option, the episode title.'=>'The display label of the option, the episode title.','The options that will be displayed in the episode selection UI'=>'The options that will be displayed in the episode selection UI','Invalid Cloudflare Analytics ID'=>'Invalid Cloudflare Analytics ID','Whether we should return the episodes list for use in the selection UI'=>'Whether we should return the episodes list for use in the selection UI','Site not registered.'=>'Site not registered.','Attachment meta was not found.'=>'Attachment meta was not found.','This attachment cannot be updated yet.'=>'This attachment cannot be updated yet.','The post id for the attachment.'=>'The post ID for the attachment.','A list of unique identifiers for fetching specific podcast episodes.'=>'A list of unique identifiers for fetching specific podcast episodes.','VideoPress Data'=>'VideoPress Data','The episode description with allowed html tags.'=>'The episode description with allowed HTML tags.','Edit post'=>'Edit post','Connect to Stripe in the editor to use this block on your site.'=>'Connect to Stripe in the editor to use this block on your site.','Connect to Stripe to use this block on your site.'=>'Connect to Stripe to use this block on your site.','Log In'=>'Log In','Private'=>'Private','Sunset'=>'Sunset','Sakura'=>'Sakura','Powder Snow'=>'Powder Snow','Nightfall'=>'Nightfall','Contrast'=>'Contrast','Classic Dark'=>'Classic Dark','Classic Bright'=>'Classic Bright','the author'=>'the author','Add New Site'=>'Add new site','Classic Blue'=>'Classic Blue','Aquatic'=>'Aquatic','The track was not found.'=>'The track was not found.','Video meta updated successfully.'=>'Video meta updated successfully.','Display the share menu in the player.'=>'Display the share menu in the player.','The description of the video.'=>'The description of the video.','The title of the video.'=>'The title of the video.','The video content rating. One of G, PG-13 or R-17'=>'The video content rating. One of G, PG-13, or R-17','Submit a form.'=>'Submit a form.','Slug of the admin color scheme.'=>'Slug of the admin colour scheme.','Play story in new tab'=>'Play story in new tab','Make a reservation'=>'Make a reservation','Slide to compare images'=>'Slide to compare images','YouTube Error: missing id and/or list'=>'YouTube Error: missing id and/or list','YouTube Poster'=>'YouTube Poster','Sorry, you are not allowed to view menus on this site.'=>'Sorry, you are not allowed to view menus on this site.','Save every change and get back online quickly with one-click restores.'=>'Save every change and get back online quickly with one-click restores.','Automatically clear spam from comments and forms.'=>'Automatically clear spam from comments and forms.','Store contact form submissions in your CRM'=>'Store contact form submissions in your CRM','The name to display in the profile of the connected account'=>'The name to display in the profile of the connected account','Profile picture of the connected account'=>'Profile picture of the connected account','Missing or invalid extension parameter.'=>'Missing or invalid extension parameter.','Reconnect Jetpack now'=>'Reconnect Jetpack now','The test timed out which may sometimes indicate a failure or may be a false failure. Please relaunch tests.'=>'The test timed out, which may sometimes indicate a failure or may be a false failure. Please relaunch tests.','We recommend either upgrading the user (%s) or reconnecting Jetpack.'=>'We recommend either upgrading the user (%s), or reconnecting Jetpack.','Token health check failed to validate tokens.'=>'Token health check failed to validate tokens.','Invalid Jetpack connection tokens.'=>'Invalid Jetpack connection tokens.','Expand'=>'Expand','The Jetpack Forms extension could not be activated.'=>'The Jetpack Forms extension could not be activated.','Search Input Overlay Trigger'=>'Search Input Overlay Trigger','Open when user starts typing'=>'Open when user starts typing','Jetpack is not connected. No blog token to check.'=>'Jetpack is not connected. No blog token to check.','Choose an amount'=>'Choose an amount','Consent'=>'Consent','Can we send you an email from time to time?'=>'Can we send you an email from time to time?','By submitting your information, you\'re giving us permission to email you. You may unsubscribe at any time.'=>'By submitting your information, you\'re giving us permission to email you. You may unsubscribe at any time.','Activated %s'=>'Activated %s','Plugin %s is already active.'=>'Plugin %s is already active.','You did not specify a plugin.'=>'You did not specify a plugin.','Status parameter missing.'=>'Status parameter missing.','Unable to determine what plugin was installed.'=>'Unable to determine what plugin was installed.','Installed %s'=>'Installed %s','Unable to install %1$s: %2$s '=>'Unable to install %1$s: %2$s ','Failed fetching site data from WordPress.com (%s). If the problem persists, try reconnecting Jetpack.'=>'Failed fetching site data from WordPress.com (%s). If the problem persists, try reconnecting Jetpack.','site_id_missing'=>'site_id_missing','The plugin activation status.'=>'The plugin activation status.','WordPress.org plugin directory slug.'=>'WordPress.org plugin directory slug.','There was an error installing Creative Mail.'=>'There was an error installing Creative Mail.','Real-time backups save every change, and one-click restores get you back online quickly.'=>'Real-time backups save every change, and one-click restores get you back online quickly.','Story'=>'Story','One-Time'=>'One-Time','Donate yearly'=>'Donate yearly','Donate monthly'=>'Donate monthly','Donate'=>'Donate','Your contribution is appreciated.'=>'Your contribution is appreciated.','Or enter a custom amount'=>'Or enter a custom amount','Make a yearly donation'=>'Make a yearly donation','Make a monthly donation'=>'Make a monthly donation','Make a one-time donation'=>'Make a one-time donation','Jetpack CRM'=>'Jetpack CRM','Error retrieving media'=>'Error retrieving media','New images may take up to 15 minutes to show up on your site.'=>'New images may take up to 15 minutes to show up on your site.','Number of columns:'=>'Number of columns:','Number to display:'=>'Number to display:','<strong>Connected Instagram Account</strong><br /> <a target="_blank" rel="noopener noreferrer" href="%1$s">%2$s</a> | <a href="%3$s">remove</a>'=>'<strong>Connected Instagram Account</strong><br /> <a target="_blank" rel="noopener noreferrer" href="%1$s">%2$s</a> | <a href="%3$s">remove</a>','Having trouble? Try <a href="%s" target="_blank" rel="noopener noreferrer">logging into the correct account</a> on Instagram.com first.'=>'Having trouble? Try <a href="%s" target="_blank" rel="noopener noreferrer">logging into the correct account</a> on Instagram.com first.','Privacy settings'=>'Privacy settings','Report this ad'=>'Report this ad','Connect Instagram Account'=>'Connect Instagram Account','Instagram is currently experiencing connectivity issues, please try again later to connect.'=>'Instagram is currently experiencing connectivity issues, please try again later to connect.','<strong>Important: You must first click Publish to activate this widget <em>before</em> connecting your account.</strong> After saving the widget, click the button below to connect your Instagram account.'=>'<strong>Important: you must first click Publish to activate this widget <em>before</em> connecting your account.</strong> After saving the widget, click the button below to connect your Instagram account.','In order to continue using this widget you must reconnect to Instagram.'=>'In order to continue using this widget, you must reconnect to Instagram.','Missing or invalid security nonce.'=>'Missing or invalid security nonce.','No Instagram images were found.'=>'No Instagram images were found.','There was an error retrieving images from Instagram. An attempt will be remade in a few minutes.'=>'There was an error retrieving images from Instagram. An attempt will be remade in a few minutes.','In order to use this Instagram widget, you must <a href="%s">configure it</a> first.'=>'In order to use this Instagram widget, you must <a href="%s">configure it</a> first.','In order to continue using this widget you must <a href="%s">reconnect to Instagram</a>.'=>'In order to continue using this widget, you must <a href="%s">reconnect to Instagram</a>.','The response was invalid'=>'The response was invalid','Display your latest Instagram photos.'=>'Display your latest Instagram photos.','The token id was empty'=>'The token id was empty','The images were missing'=>'The images were missing','Jetpack is in Offline Mode:'=>'Jetpack is in Offline Mode:','The post ID to attach the upload to.'=>'The post ID to attach the upload to.','Excluded Post Types'=>'Excluded Post Types','The requested Instagram connection is not available anymore.'=>'The requested Instagram connection is not available anymore.','Show scrollbar'=>'Show scrollbar','Maximum width (in pixels; 220 to 1200):'=>'Maximum width (in pixels; 220 to 1200):','Number of tweets in the timeline (1 to 20):'=>'Number of tweets in the timeline (1 to 20):','Border color (in hex format):'=>'Border colour (in hex format):','Color scheme:'=>'Colour scheme:','Show header'=>'Show header','Show borders'=>'Show borders','Instagram'=>'Instagram','Number of tweets shown:'=>'Number of tweets shown:','Fixed'=>'Fixed','Show footer'=>'Show footer','Height (in pixels; at least 200):'=>'Height (in pixels; at least 200):','Dynamic'=>'Dynamic','Loading new page'=>'Loading new page','Page: %1$d.'=>'Page: %1$d.','Customize buttons'=>'Customise buttons','The %1$s file will be removed from the Jetpack plugin in version %2$s.'=>'The %1$s file will be removed from the Jetpack plugin in version %2$s.','The %1$s function will be removed from the Jetpack plugin in version %2$s.'=>'The %1$s function will be removed from the Jetpack plugin in version %2$s.','The jetpack_offline_mode filter is set to true.'=>'The jetpack_offline_mode filter is set to true.','The site URL is a known local development environment URL (e.g. http://localhost).'=>'The site URL is a known local development environment URL (eg http://localhost).','The WP_LOCAL_DEV constant is defined in wp-config.php or elsewhere.'=>'The WP_LOCAL_DEV constant is defined in wp-config.php or elsewhere.','Jetpack is not in Offline Mode.'=>'Jetpack is not in Offline Mode.','Post'=>'Post','No results for "%s"'=>'No results for "%s"','Searching…'=>'Searching…','Search…'=>'Search…','Oldest'=>'Oldest','Tag'=>'Tag','Page'=>'Page','Google Photos'=>'Google Photos','Filters'=>'Filters','Images'=>'Images','Pexels free photos'=>'Pexels free photos','You are not connected to that service.'=>'You are not connected to that service.','Sorry, you are not allowed to upload media on this site.'=>'Sorry, you are not allowed to upload media on this site.','Sorry, you are not allowed to create posts as this user.'=>'Sorry, you are not allowed to create posts as this user.','Cannot create existing post.'=>'Cannot create existing post.','Blog token is missing.'=>'Blog token is missing.','Privacy Policy URL'=>'Privacy Policy URL','Enable support for California Consumer Privacy Act'=>'Enable support for the California Consumer Privacy Act','Custom ads.txt'=>'Custom ads.txt','Failed fetching site data from WordPress.com. If the problem persists, try reconnecting Jetpack.'=>'Failed fetching site data from WordPress.com. If the problem persists, try reconnecting Jetpack.','You have used your space quota. Please delete files before uploading.'=>'You have used your space quota. Please delete files before uploading.','This file is too big. Files must be less than %s KB in size.'=>'This file is too big. Files must be less than %s KB in size.','Not enough space to upload. %s KB needed.'=>'Not enough space to upload. %s KB needed.','Could not retrieve source URL.'=>'Could not retrieve source URL.','Media data to copy.'=>'Media data to copy.','Number of media items in the request'=>'Number of media items in the request','Media collection search term.'=>'Media collection search term.','Always allowed IP addresses'=>'Always allowed IP addresses','Add a Pay with PayPal button as a Widget.'=>'Add a Pay with PayPal button as a Widget.','Select a Pay with PayPal button:'=>'Select a Pay with PayPal button:','Pageview Description:'=>'Page View Description:','Enable infinite scrolling'=>'Enable infinite scrolling','Show sort selector'=>'Show sort selector','Additional Jetpack Search Settings'=>'Additional Jetpack Search Settings','Minimal'=>'Minimal','Choose how the search results look.'=>'Choose how the search results look.','Result Format'=>'Result Format','Select when your overlay should appear.'=>'Select when your overlay should appear.','Default Sort'=>'Default Sort','Pick the initial sort for your search results.'=>'Pick the initial sort for your search results.','Select a theme for your search overlay.'=>'Select a theme for your search overlay.','View Privacy Policy'=>'View Privacy Policy','On'=>'On','Off'=>'Off','Close dialog'=>'Close dialogue','After you opt-out you may still see ads, including personalized ones, on this site and other sites - they just won\'t be personalized based on information from your visits to this site.'=>'After you opt out, you may still see ads, including personalised ones, on this site and other sites – they just won\'t be personalised based on information from your visits to this site.','%s has been added to the always allowed list.'=>'%s has been added to the always allowed list.','Cleared all IPs from the always allow list.'=>'Cleared all IPs from the always allow list.','Always allow list is empty.'=>'Always allow list is empty.','Here are your always allowed IPs:'=>'Here are your always allowed IPs:','%s is already on the always allow list.'=>'%s is already on the always allow list.','Google Map Embed'=>'Google Maps Embed','You aren’t authorized to do that.'=>'You aren’t authorised to do that.','This opt-out is managed through cookies, so if you delete cookies, your browser is set to delete cookies automatically after a certain length of time, or if you visit this site with a different browser, you\'ll need to make this selection again.'=>'This opt-out is managed through cookies, so if you delete cookies, your browser is set to delete cookies automatically after a certain length of time, or if you visit this site with a different browser, you\'ll need to make this selection again.','We never share information that identifies you personally, like your name or email address, as part of the advertising program.'=>'We never share information that identifies you personally, like your name or email address, as part of the advertising program.','Please Wait'=>'Please Wait','Feedback Form'=>'Feedback Form','Appointment Form'=>'Appointment Form','Registration Form'=>'Registration Form','RSVP Form'=>'RSVP Form','Contact Us'=>'Contact Us','Could not retrieve Scan state.'=>'Could not retrieve Scan state.','Scan state correctly received.'=>'Scan state correctly received.','%s must be an object.'=>'%s must be an object.','(Only administrators and the post author will see this message.)'=>'(Only administrators and the post author will see this message.)','%s Threats found'=>'%s Threats found','%s Threat found'=>'%s Threat found' . "\0" . '%s Threats found','Show comments area in carousel'=>'Show comments area in carousel','Rating: %1$s out of %2$s.'=>'Rating: %1$s out of %2$s.','An error occurred in the Latest Instagram Posts block. Please try again later.'=>'An error occurred in the Latest Instagram Posts block. Please try again later.','Connecting…'=>'Connecting…','Button'=>'Button','One or more tests did not pass. Please investigate!'=>'One or more tests did not pass. Please investigate!','How many Instagram posts?'=>'How many Instagram posts?','An Instagram Keyring access token.'=>'An Instagram Keyring access token.','Jetpack Scan'=>'Jetpack Scan','Click to access %1$s'=>'Click to access %1$s','View this document on Scribd'=>'View this document on Scribd','Print page'=>'Print page','Please try again later.'=>'Please try again later.','Your site is not connected to Jetpack'=>'Your site is not connected to Jetpack','Show price'=>'Show price','Google Calendar'=>'Google Calendar','Add Form'=>'Add Form','No tracks available to play.'=>'No tracks available to play.','Your podcast URL is invalid and couldn\'t be embedded. Please double check your URL.'=>'Your podcast URL is invalid and couldn\'t be embedded. Please double check your URL.','No Podcast URL provided. Please enter a valid Podcast RSS feed URL.'=>'No Podcast URL provided. Please enter a valid Podcast RSS Feed URL.','Account not found. If you already have an account, make sure you have connected to WordPress.com.'=>'Account not found. If you already have an account, make sure you have connected to WordPress.com.','Brute force attack protection is inactive.'=>'Brute force attack protection is inactive.','Brute force attack protection'=>'Brute force attack protection','Module NameWooCommerce Analytics'=>'WooCommerce Analytics','Instant search and filtering to help visitors quickly find relevant answers and explore your site.'=>'Instant search and filtering to help visitors quickly find relevant answers and explore your site.','Use Small Header'=>'Use Small Header','Help visitors quickly find answers with highly relevant instant search results and powerful filtering.'=>'Help visitors quickly find answers with highly relevant instant search results and powerful filtering.','You must have Two-Step Authentication enabled on your WordPress.com account.'=>'You must have Two-Step Authentication enabled on your WordPress.com account.','Could not accept the Terms of Service. Please try again later.'=>'Could not accept the Terms of Service. Please try again later.','Display "Powered by Jetpack"'=>'Display "Powered by Jetpack"','Choose a color to highlight matching search terms.'=>'Choose a colour to highlight matching search terms.','Highlight Search Terms'=>'Highlight Search Terms','Customize the sidebar inside the Jetpack Search overlay'=>'Customise the sidebar inside the Jetpack Search overlay','Jetpack Search Sidebar'=>'Jetpack Search Sidebar','Something got a little mixed up and an unexpected WordPress.com user logged in.'=>'Something got a little mixed up and an unexpected WordPress.com user logged in.','Site products correctly received.'=>'Site products correctly received.','The episode title.'=>'The episode title.','The episode description, in plaintext.'=>'The episode description, in plain text.','The mime type of the episode.'=>'The MIME type of the episode.','The audio file URL of the episode.'=>'The audio file URL of the episode.','The external link for the episode.'=>'The external link for the episode.','The episode id. Generated per request, not globally unique.'=>'The episode ID. Generated per request, not globally unique.','Latest episodes of the podcast.'=>'Latest episodes of the podcast.','The URL of the podcast cover image.'=>'The URL of the podcast cover image.','The URL of the podcast website.'=>'The URL of the podcast website.','The title of the podcast.'=>'The title of the podcast.','The Podcast RSS feed URL.'=>'The Podcast RSS Feed URL.','Podcast audio is an invalid type.'=>'Podcast audio is an invalid type.','Podcast audio RSS feed has no tracks.'=>'Podcast audio RSS Feed has no tracks.','Your podcast couldn\'t be embedded. Please double check your URL.'=>'Your podcast couldn\'t be embedded. Please double check your URL.','Your Podcast couldn\'t be embedded as it doesn\'t contain any tracks. Please double check your URL.'=>'Your Podcast couldn\'t be embedded as it doesn\'t contain any tracks. Please double check your URL.','Jetpack.com detected an error on the WP.com Self Test. Visit the Jetpack Debug page for more info: %1$s, or contact support.'=>'Jetpack.com detected an error on the WP.com Self Test. Visit the Jetpack Debug page for more info: %1$s, or contact support.','See Github for more on Sync Settings'=>'See GitHub for more on Sync Settings','Jetpack Sync has been disabled on your site.'=>'Jetpack Sync has been disabled on your site.','Contact Jetpack Support'=>'Contact Jetpack Support','The server port value is unexpected.
						Try adding the following to your wp-config.php file: %1$s'=>'The server port value is unexpected.
						Try adding the following to your wp-config.php file: %1$s','The server port values are not defined. This is most common when running PHP via a CLI.'=>'The server port values are not defined. This is most common when running PHP via a CLI.','View our server requirements'=>'View our server requirements','Please ask your hosting provider to refer to our server requirements and enable PHP\'s XML module.'=>'Please ask your hosting provider to refer to our server requirements and enable PHP\'s XML module.','Your server did not successfully connect to the Jetpack server using %1$s
				Please ask your hosting provider to confirm your server can make outbound requests to jetpack.com.'=>'Your server did not successfully connect to the Jetpack server using %1$s
				Please ask your hosting provider to confirm your server can make outbound requests to Jetpack.com.','We recommend reconnecting Jetpack.'=>'We recommend reconnecting Jetpack.','Error'=>'Error','Your site is connected to Jetpack.'=>'Your site is connected to Jetpack.','Passed'=>'Passed','A healthy connection ensures Jetpack essential services are provided to your WordPress site, such as Stats and Site Security.'=>'A healthy connection ensures Jetpack essential services are provided to your WordPress site, such as Stats and Site Security.','Your site is connected to Jetpack'=>'Your site is connected to Jetpack','Trigger an auto config of instant search'=>'Trigger an auto config of instant search','Has an active Jetpack Search product purchase'=>'Has an active Jetpack Search product purchase','Enable Instant Search'=>'Enable Instant Search','Test failed!'=>'Test failed!','The source of the API key. Defaults to "site"'=>'The source of the API key. Defaults to "site"','The status code of the URL\'s response.'=>'The status code of the URL\'s response.','Register on Eventbrite'=>'Register on Eventbrite','Schedule time with me'=>'Schedule time with me','Site purchases correctly received.'=>'Site purchases correctly received.','The final destination of the URL being checked for redirects.'=>'The final destination of the URL being checked for redirects.','The URL to check for redirects.'=>'The URL to check for redirects.','Manage subscription'=>'Manage subscription','YouTube Error: empty URL args'=>'YouTube Error: empty URL args','YouTube Error: bad URL entered'=>'YouTube Error: bad URL entered','recipePrep Time'=>'Prep Time','recipeCook Time'=>'Cook Time','recipeNutrition'=>'Nutrition','recipeRating'=>'Rating','Pause Slideshow'=>'Pause Slideshow','Go to slide %d'=>'Go to slide %d','Previous Slide'=>'Previous Slide','Next Slide'=>'Next Slide','The site is not currently connected, so nothing to do!'=>'The site is not currently connected, so nothing to do!','Show Timeline'=>'Show Timeline','Custom post description to be used in HTML <meta /> tag.'=>'Custom post description to be used in HTML <meta /> tag.','Visitors tracked by Jetpack'=>'Visitors tracked by Jetpack','Helper script body must be base64 encoded'=>'Helper script body must be base64 encoded','You must specify a helper script body'=>'You must specify a helper script body','You must specify a helper script path'=>'You must specify a helper script path','Play Slideshow'=>'Play Slideshow','Archive.org'=>'Archive.org','Archive.org Book'=>'Archive.org Book','Site benefits correctly received.'=>'Site benefits correctly received.','The number of times visitors have shared your posts with the world using Jetpack'=>'The number of times visitors have shared your posts with the world using Jetpack','Live social media site connections, powered by Jetpack'=>'Live social media site connections, powered by Jetpack','Ad-free, lightning-fast videos delivered by Jetpack'=>'Ad-free, lightning-fast videos delivered by Jetpack','Super-fast, mobile-ready images served by Jetpack'=>'Super-fast, mobile-ready images served by Jetpack','Image Hosting'=>'Image Hosting','Form submissions stored by Jetpack'=>'Form submissions stored by Jetpack','Contact Form Feedback'=>'Contact Form Feedback','The number of times Jetpack has backed up your site and kept it safe'=>'The number of times Jetpack has backed up your site and kept it safe','Jetpack Backup'=>'Jetpack Backup','People subscribed to your updates through Jetpack'=>'People subscribed to your updates through Jetpack','Subscribers'=>'Subscribers','The number of malicious login attempts blocked by Jetpack'=>'The number of malicious login attempts blocked by Jetpack','Brute force protection'=>'Brute force protection','Please enter a valid Google API Key.'=>'Please enter a valid Google API Key.','https://jetpack.com/support/multisite-protect'=>'https://jetpack.com/support/multisite-protect','Open images in new tab?'=>'Open images in new tab?','Your installation of Jetpack is incomplete. If you installed Jetpack from GitHub, please refer to this document to set up your development environment: %1$s'=>'Your installation of Jetpack is incomplete. If you installed Jetpack from GitHub, please refer to this document to set up your development environment: %1$s','Include a small chart in your admin bar with a 48-hour traffic snapshot.'=>'Include a small chart in your Admin Bar with a 48-hour traffic snapshot.','User not found.'=>'User not found.','Invalid user identifier.'=>'Invalid user identifier.','Scan'=>'Scan','Deleted %1$d %2$s options'=>'Deleted %1$d %2$s options','No options were deleted.'=>'No options were deleted.','Successfully reset %1$s on %2$d sites.'=>'Successfully reset %1$s on %2$d sites.','Deleted %1$d %2$s options from %3$s'=>'Deleted %1$d %2$s options from %3$s','Please specify if you would like to reset your options, modules or sync-checksum'=>'Please specify if you would like to reset your options, modules or sync-checksum','The following messages will give you preview of what will happen when you run this command.

'=>'The following messages will give you a preview of what will happen when you run this command.

','No actions will be taken.
'=>'No actions will be taken.
','
This is a dry run.
'=>'
This is a dry run.
','Plugin icon'=>'Plugin icon','Unknown security token.'=>'Unknown security token.','Please specify a Soundcloud URL.'=>'Please specify a Soundcloud URL.','Something is wrong with your Wufoo shortcode. Try following the instructions <a href="%s" target="_blank" rel="noopener noreferrer">here</a> to embed a form on your site.'=>'Something is wrong with your Wufoo shortcode. Try following the instructions <a href="%s" target="_blank" rel="noopener noreferrer">here</a> to embed a form on your site.','You did not provide a valid Medium URL.'=>'You did not provide a valid Medium URL.','View at Medium.com'=>'View at Medium.com','View this collection on Medium.com'=>'View this collection on Medium.com','Recurring Payments plans'=>'Recurring Payments plans','The WordPress.com API returned a 404 error.'=>'The WordPress.com API returned a 404 error.','About'=>'About','No activity found'=>'No activity found','Could not retrieve site activity.'=>'Could not retrieve site activity.','Site ID is missing.'=>'Site ID is missing.','Your version of WordPress (%1$s) is lower than the version required by Jetpack (%2$s). Please update WordPress to continue enjoying Jetpack.'=>'Your version of WordPress (%1$s) is lower than the version required by Jetpack (%2$s). Please update WordPress to continue enjoying Jetpack.','Yearly'=>'Yearly','Monthly'=>'Monthly','Uploading…'=>'Uploading…','Mailchimp'=>'Mailchimp','Pay with PayPal'=>'Pay with PayPal','ID'=>'ID','Form'=>'Form','Processing…'=>'Processing…','Success! You\'re on the list.'=>'Success! You\'re on the list.','Whoops! There was an error and we couldn\'t process your subscription. Please reload the page and try again.'=>'Whoops! There was an error and we couldn\'t process your subscription. Please reload the page and try again.','Closed'=>'Closed','site_id is required'=>'site_id is required','access_token_secret is required'=>'access_token_secret is required','access_token is required'=>'access_token is required','WooCommerce auth data is already set.'=>'WooCommerce auth data is already set.','By clicking submit, you agree to share your email address with the site owner and Mailchimp to receive marketing, updates, and other emails from the site owner. Use the unsubscribe link in those emails to opt out at any time.'=>'By clicking submit, you agree to share your e-mail address with the site owner and MailChimp to receive marketing, updates, and other e-mails from the site owner. Use the unsubscribe link in those e-mails to opt out at any time.','Object not found'=>'Object not found','Specified object_type not recognized'=>'Specified object_type not recognised','You must specify both an object type and id to fetch'=>'You must specify both an object type and id to fetch','Jetpack requires a more recent version of WordPress and has been paused. Please update WordPress to continue enjoying Jetpack.'=>'Jetpack requires a more recent version of WordPress and has been paused. Please update WordPress to continue enjoying Jetpack.','Enter your email'=>'Enter your e-mail','Join my email list'=>'Join my e-mail list','Error writing new %s'=>'Error writing new %s','Error fetching contents of %s'=>'Error fetching contents of %s','No files were created'=>'No files were created','Error creating %s'=>'Error creating %s','Name conflicts with the existing block %s'=>'Name conflicts with the existing block %s','Can\'t write files'=>'Can\'t write files','Invalid block slug. They can contain only lowercase alphanumeric characters or dashes, and start with a letter'=>'Invalid block slug. They can contain only lowercase alphanumeric characters or dashes, and start with a letter','The title parameter is required.'=>'The title parameter is required.','Invalid subcommand %s.'=>'Invalid subcommand %s.','Successfully created block %1$s with slug %2$s'=>'Successfully created block %1$s with slug %2$s','Read more at %7$s'=>'Read more at %7$s','The block slug has been added to the %4$s list at %5$s'=>'The block slug has been added to the %4$s list at %5$s','The files were created at %3$s'=>'The files were created at %3$s','To start using the block, build the blocks with pnpm run build-extensions'=>'To start using the block, build the blocks with pnpm run build-extensions','Jetpack is currently in offline mode, so the Jetpack Social module will not load.'=>'Jetpack is currently in offline mode, so the Jetpack Social module will not load.','Jetpack is current in offline mode because the site url does not contain a \'.\', which often occurs when dynamically setting the WP_SITEURL constant. While in offline mode, the Jetpack Social module will not load.'=>'Jetpack is current in offline mode because the site URL does not contain a \'.\', which often occurs when dynamically setting the WP_SITEURL constant. While in offline mode, the Jetpack Social module will not load.','Both `pass` and `kpri` fields cannot be blank.'=>'Both "pass" and "kpri" fields cannot be blank.','`%s` cannot be empty.'=>'"%s" cannot be empty.','Jetpack sync is not currently allowed for this site. The site is in safe mode.'=>'Jetpack sync is not currently allowed for this site. The site is in safe mode.','A non-empty nonce must be supplied.'=>'A non-empty nonce must be supplied.','Failed to fetch user token from WordPress.com.'=>'Failed to fetch user token from WordPress.com.','Jetpack is already connected.'=>'Jetpack is already connected.','Valid user is required.'=>'Valid user is required.','Sync Settings:'=>'Sync Settings:','Sync Status:'=>'Sync Status:','Your password is too weak: Looks like you\'re including easy to guess information about yourself. Try something a little more unique.'=>'Your password is too weak: Looks like you\'re including easy to guess information about yourself. Try something a little more unique.','This is a very common password. Choose something that will be harder for others to guess.'=>'This is a very common password. Choose something that will be harder for others to guess.','This password is too easy to guess: you can improve it by including special characters such as !#=?*&.'=>'This password is too easy to guess: you can improve it by including special characters such as !#=?*&.','This password is too easy to guess: you can improve it by mixing both letters and numbers.'=>'This password is too easy to guess: you can improve it by mixing both letters and numbers.','This password is too easy to guess: you can improve it by adding additional uppercase letters, lowercase letters, or numbers.'=>'This password is too easy to guess: you can improve it by adding additional uppercase letters, lowercase letters, or numbers.','Jetpack sync is not currently allowed for this site. Jetpack is not connected.'=>'Jetpack sync is not currently allowed for this site. Jetpack is not connected.','Jetpack sync is not currently allowed for this site. It is currently disabled. Run `wp jetpack sync enable` to enable it.'=>'Jetpack sync is not currently allowed for this site. It is currently disabled. Run "wp jetpack sync enable" to enable it.','Please specify what type of queue do you want to reset: `full` or `regular`.'=>'Please specify what type of queue you want to reset: "full" or "regular".','Reset Full Sync Queue on %s'=>'Reset Full Sync Queue on %s','Reset Regular Sync Queue on %s'=>'Reset Regular Sync Queue on %s','Reset Full Sync and Regular Queues Queue on %s'=>'Reset Full Sync and Regular Queues Queue on %s','Sync Disabled on %s. Use `wp jetpack sync enable` to enable syncing again.'=>'Sync Disabled on %s. Use "wp jetpack sync enable" to enable syncing again.','Sync Enabled on %s'=>'Sync Enabled on %s','Sync Disabled on %s'=>'Sync Disabled on %s','Jetpack sync is not currently allowed for this site. The site is in offline mode.'=>'Jetpack sync is not currently allowed for this site. The site is in offline mode.','Diagnostic information helpful to <a href="%1$s" target="_blank" rel="noopener noreferrer">your Jetpack Happiness team<span class="screen-reader-text">%2$s</span></a>'=>'Diagnostic information helpful to <a href="%1$s" target="_blank" rel="noopener noreferrer">your Jetpack Happiness team<span class="screen-reader-text">%2$s</span></a>','<a href="%1$s">Contact our Happiness team</a>. When you do, please include the <a href="%2$s">full debug information from your site</a>.'=>'<a href="%1$s">Contact our Happiness team</a>. When you do, please include the <a href="%2$s">full debug information from your site</a>.','Could not calculate resized image dimensions'=>'Could not calculate resized image dimensions','Ask us for help!'=>'Ask us for help!','Still having trouble?'=>'Still having trouble?','Password must be at least %d characters.'=>'Password must be at least %d characters.','Passwords may not contain the character "\\".'=>'Passwords may not contain the character "\\".','Master user no longer exists. Please disconnect and reconnect Jetpack.'=>'Master user no longer exists. Please disconnect and reconnect Jetpack.','No master user set.'=>'No master user set.','Jetpack Tests'=>'Jetpack Tests','This test successfully passed!'=>'This test successfully passed!','Jetpack: '=>'Jetpack: ','Tests must be valid PHP callables.'=>'Tests must be valid PHP callables.','Test names must be unique.'=>'Test names must be unique.','add_test arguments changed in 7.3.0. Please reference inline documentation.'=>'add_test arguments changed in 7.3.0. Please reference inline documentation.','(opens in a new tab)'=>'(opens in a new tab)','Navigation itemModules'=>'Modules','TEST RESULTS:'=>'TEST RESULTS:','Jetpack is not connected.'=>'Jetpack is not connected.','Jetpack is not connected. No master user to check.'=>'Jetpack is not connected. No master user to check.','Connection test failed (empty response body)'=>'Connection test failed (empty response body)','Connection test failed (#%1$s: %2$s)'=>'Connection test failed (#%1$s: %2$s)','Navigation itemNetwork Sites'=>'Network Sites','Navigation itemNetwork Settings'=>'Network Settings','Navigation itemSites'=>'Sites','Manage your network\'s Jetpack Sites.'=>'Manage your network\'s Jetpack Sites.','There was another problem:'=>'There was another problem:','Resolve'=>'Resolve','Jetpack\'s async local testing suite passed all tests!'=>'Jetpack\'s async local testing suite passed all tests!','Jetpack passed all async tests.'=>'Jetpack passed all async tests.','Please contact Jetpack support.'=>'Please contact Jetpack support.','There is no test by that name: '=>'There is no test by that name: ','PHP XML manipulation libraries are not available.'=>'PHP XML manipulation libraries are not available.','Test passed!'=>'Test passed!','The user (%s) who set up the Jetpack connection is not an administrator.'=>'The user (%s) who set up the Jetpack connection is not an administrator.','The user who set up the Jetpack connection no longer exists on this site.'=>'The user who set up the Jetpack connection no longer exists on this site.','<a href="%1$s">Please update WordPress</a>, and then <a href="%2$s">learn more about updating PHP</a>.'=>'<a href="%1$s">Please update WordPress</a>, and then <a href="%2$s">learn more about updating PHP</a>.','%s Active Installations'=>'%s Active Installations','Active plugin installationsLess Than 10'=>'Less Than 10','Active plugin installations%s+ Million'=>'%s+ Million' . "\0" . '%s+ Million','ratings'=>'ratings','More Details'=>'More Details','This plugin doesn&#8217;t work with your version of PHP.'=>'This plugin doesn&#8217;t work with your version of PHP.','This plugin doesn&#8217;t work with your version of WordPress.'=>'This plugin doesn&#8217;t work with your version of WordPress.','<a href="%s">Learn more about updating PHP</a>.'=>'<a href="%s">Learn more about updating PHP</a>.','<a href="%s">Please update WordPress</a>.'=>'<a href="%s">Please update WordPress</a>.','pluginActive'=>'Active','Update Now'=>'Update Now','Update %s now'=>'Update %s now','pluginCannot Install'=>'Cannot Install','Install Now'=>'Install Now','Install %s now'=>'Install %s now','This plugin doesn&#8217;t work with your versions of WordPress and PHP.'=>'This plugin doesn&#8217;t work with your versions of WordPress and PHP.','pluginInstalled'=>'Installed','pluginNetwork Activate %s'=>'Network Activate %s','Network Activate'=>'Network Activate','pluginActivate %s'=>'Activate %s','For even more of our WordPress plugins, please take a look at <a href="https://profiles.wordpress.org/automattic/#content-plugins" target="_blank" rel="noopener noreferrer" class="jptracks" data-jptracks-name="jetpack_about_wporg_profile">our WordPress.org profile</a>.'=>'For even more of our WordPress plugins, please take a look at <a href="https://profiles.wordpress.org/automattic/#content-plugins" target="_blank" rel="noopener noreferrer" class="jptracks" data-jptracks-name="jetpack_about_wporg_profile">our WordPress.org profile</a>.','Popular WordPress services by Automattic'=>'Popular WordPress services by Automattic','Come work with us'=>'Come work with us','We believe in Open Source and the vast majority of our work is available under the GPL.'=>'We believe in Open Source and the vast majority of our work is available under the GPL.','We’re a distributed company with over %1$s Automatticians in more than %2$s countries speaking at least %3$s different languages. Our common goal is to democratize publishing so that anyone with a story can tell it, regardless of income, gender, politics, language, or where they live in the world.'=>'We’re a distributed company with over %1$s Automatticians in more than %2$s countries speaking at least %3$s different languages. Our common goal is to democratise publishing so that anyone with a story can tell it, regardless of income, gender, politics, language, or where they live in the world.','We are the people behind WordPress.com, WooCommerce, Jetpack, Simplenote, Longreads, VaultPress, Akismet, Gravatar, Crowdsignal, Cloudup, and more. We believe in making the web a better place.'=>'We are the people behind WordPress.com, WooCommerce, Jetpack, Simplenote, Longreads, VaultPress, Akismet, Gravatar, Crowdsignal, Cloudup, and more. We believe in making the web a better place.','Learn more about us'=>'Learn more about us','Could not retrieve Backup & Scan data.'=>'Could not retrieve Backup & Scan data.','Backup & Scan data correctly received.'=>'Backup & Scan data correctly received.','Please connect your user account to WordPress.com'=>'Please connect your user account to WordPress.com','Meet the Automattic team'=>'Meet the Automattic team','Unique VideoPress ID'=>'Unique VideoPress ID','Sorry, something is wrong with your Jetpack connection.'=>'Sorry, something is wrong with your Jetpack connection.','All connection tests passed.'=>'All connection tests passed.','User friendly message'=>'User-friendly message','The name of the service in question'=>'The name of the service in question','Displays success if the operation was successfully executed and an error code if it was not'=>'Displays success if the operation was successfully executed and an error code if it was not','The API key used by the service. Empty if none has been set yet'=>'The API key used by the service. Empty if none has been set yet','Can\'t connect to Mapbox'=>'Can\'t connect to Mapbox','Invalid Service'=>'Invalid Service','API key deleted successfully.'=>'API key deleted successfully.','API key updated successfully.'=>'API key updated successfully.','Invalid API Key'=>'Invalid API Key','API key retrieved successfully.'=>'API key retrieved successfully.','Method \'%s\' must be overridden.'=>'Method \'%s\' must be overridden.','You are not allowed to access the \'%s\' field.'=>'You are not allowed to access the \'%s\' field.','Method \'%s\' must return either true or WP_Error.'=>'Method \'%s\' must return either true or WP_Error.','Property \'%s\' must be overridden.'=>'Property \'%s\' must be overridden.','Site is under construction and cannot be verified'=>'Site is under construction and cannot be verified','Back to Jetpack Dashboard'=>'Back to Jetpack Dashboard','About Jetpack'=>'About Jetpack','Creating product has failed.'=>'Creating product has failed.','Sorry, you are not allowed to access Jetpack Social data for this post.'=>'Sorry, you are not allowed to access Jetpack Social data for this post.','Message instructing the user to refresh their Connection to the Jetpack Social service'=>'Message instructing the user to refresh their Connection to the Jetpack Social service','Reason for the extension not being available'=>'Reason for the extension not being available','Whether the extension is available'=>'Whether the extension is available','Is this connection available to all users?'=>'Is this connection available to all users?','Username of the connected account'=>'Username of the connected account','Sorry, you are not allowed to access Jetpack Social data on this site.'=>'Sorry, you are not allowed to access Jetpack Social data on this site.','Sorry, Jetpack Social is not available on your site right now.'=>'Sorry, Jetpack Social is not available on your site right now.','Custom ads.txt entries'=>'Custom ads.txt entries','Site connection failed!'=>'Site connection failed!','Debugging Center'=>'Debugging Centre','By clicking <strong>Set up Jetpack</strong>, you agree to our <a href="%1$s" target="_blank" rel="noopener noreferrer">Terms of Service</a> and to <a href="%2$s" target="_blank" rel="noopener noreferrer">sync your site‘s data</a> with us.'=>'By clicking <strong>Set up Jetpack</strong>, you agree to our <a href="%1$s" target="_blank" rel="noopener noreferrer">Terms of Service</a> and to <a href="%2$s" target="_blank" rel="noopener noreferrer">sync your site‘s data</a> with us.','Are Likes enabled?'=>'Are Likes enabled?','The card could not be dismissed'=>'The card could not be dismissed','Hide this suggestion'=>'Hide this suggestion','Jetpack: Module NameJetpack: %s'=>'Jetpack: %s','Enable'=>'Enable','Keep your visitors and search engines happy by stopping comment and contact form spam with Akismet.'=>'Keep your visitors and search engines happy by stopping comment and contact form spam with Akismet.','Activate Module'=>'Activate Module','Select one'=>'Select one','Phone'=>'Phone','Activating'=>'Activating','Get started'=>'Get started','Learn more about these suggestions.'=>'Learn more about these suggestions.','This suggestion was made by Jetpack, the security and performance plugin already installed on your site.'=>'This suggestion was made by Jetpack, the security and performance plugin already installed on your site.','Are sharing buttons enabled?'=>'Are sharing buttons enabled?','Jetpack (installed)'=>'Jetpack (installed)','Module NameImage CDN'=>'Image CDN','Module NameAsset CDN'=>'Asset CDN','Module NameCopy Post'=>'Copy Post','Create a new post based on an existing post.'=>'Create a new post based on an existing post.','Our asset CDN is a site acceleration service.
		That means that we host static assets like JavaScript and CSS shipped with WordPress Core and Jetpack from our servers, alleviating the load on your server.'=>'Our asset CDN is a site acceleration service.
		That means that we host static assets like JavaScript and CSS shipped with WordPress Core and Jetpack from our servers, alleviating the load on your server.','Increase visitor engagement by adding a Like button to comments.'=>'Increase visitor engagement by adding a Like button to comments.','10 posts published by John on May 30, 2012%1$s post published by %2$l on %3$s'=>'%1$s post published by %2$l on %3$s' . "\0" . '%1$s posts published by %2$l on %3$s','10 posts publishes by John during May 2012%1$s post published by %2$l during %3$s'=>'%1$s post published by %2$l during %3$s' . "\0" . '%1$s posts published by %2$l during %3$s','10 posts published by John in the year 2012%1$s post published by %2$l in the year %3$s'=>'%1$s post published by %2$l in the year %3$s' . "\0" . '%1$s posts published by %2$l in the year %3$s','Your contribution'=>'Your contribution','Show total number of followers? (%s follower)'=>'Show total number of followers? (%s follower)' . "\0" . 'Show total number of followers? (%s followers)','Follow Button Text:'=>'Follow Button Text:','Optional text to display to logged in WordPress.com users:'=>'Optional text to display to logged in WordPress.com users:','Widget title for followers:'=>'Widget title for followers:','Widget title for non-followers:'=>'Widget title for non-followers:','Optional text to display to non-WordPress.com users:'=>'Optional text to display to non WordPress.com users:','We\'ve made some updates to Jetpack Social. Please visit the <a href=\'%s\' class=\'jptracks\' data-jptracks-name=\'legacy_publicize_settings\'>WordPress.com sharing page</a> to manage your Jetpack Social connections or use the button below.'=>'We\'ve made some updates to Jetpack Social. Please visit the <a href=\'%s\' class=\'jptracks\' data-jptracks-name=\'legacy_publicize_settings\'>WordPress.com sharing page</a> to manage your Jetpack Social connections or use the button below.','Your LinkedIn connection needs to be reauthenticated to continue working – head to Sharing to take care of it.'=>'Your LinkedIn connection needs to be reauthenticated to continue working – head to Sharing to take care of it.','Connect social media services to automatically share new posts.'=>'Connect social media services to automatically share new posts.','The message to use instead of the title when sharing to Jetpack Social services'=>'The message to use instead of the title when sharing to Jetpack Social services','Please select a Facebook Page to publish updates.'=>'Please select a Facebook Page to publish updates.','Simple payments; status.'=>'Simple payments; status.','Simple payments button; paypal email.'=>'Simple payments button; paypal email.','Simple payments; allow multiple items'=>'Simple payments; allow multiple items','Simple payments; text with "Buy" or other CTA'=>'Simple payments; text with "Buy" or other CTA','Simple payments; currency code.'=>'Simple payments; currency code.','Simple payments; price.'=>'Simple payments; price.','Secure Sign On'=>'Secure Sign On','No sitemap found. Please try again later.'=>'No sitemap found. Please try again later.','No sitemap found. The system will try to build it again in %s.'=>'No sitemap found. The system will try to build it again in %s.','Jetpack cannot load necessary XML manipulation libraries. Please ask your hosting provider to refer to our server requirements at https://jetpack.com/support/server-requirements/ .'=>'Jetpack cannot load the necessary XML manipulation libraries. Please ask your hosting provider to refer to our server requirements at https://jetpack.com/support/server-requirements/ .','Invalid price'=>'Invalid price','There was an issue retrieving stats. Please try again later.'=>'There was an issue retrieving stats. Please try again later.','Jetpack Search not supported in Offline Mode'=>'Jetpack Search not supported in Offline Mode','The following settings will impact all related posts on your site, except for those you created via the block editor:'=>'The following settings will impact all related posts on your site, except for those you created via the Block Editor:','Take Our Poll'=>'Take Our Poll','Lytro has been shut down since March 2019.'=>'Lytro has been shut down since March 2019.','The Email Subscribe shortcode is now available as a block in the Block editor.'=>'The E-mail Subscribe shortcode is now available as a block in the block editor.','The Google Video embed service is not available anymore, it has been replaced by YouTube.'=>'The Google Video embed service is not available anymore, it has been replaced by YouTube.','The Digg API was shut down in 2014.'=>'The Digg API was shut down in 2014.','The Gist ID you provided is not valid. Please try a different one.'=>'The Gist ID you provided is not valid. Please try a different one.','Please specify a Gist URL or ID.'=>'Please specify a Gist URL or ID.','Your site is incorrectly double-encoding redirects from http to https. This is preventing Jetpack from authenticating your connection. Please visit our <a href="%s">support page</a> for details about how to resolve this.'=>'Your site is incorrectly double-encoding redirects from http to https. This is preventing Jetpack from authenticating your connection. Please visit our <a href="%s">support page</a> for details about how to resolve this.','The JETPACK_DEV_DEBUG constant is defined in wp-config.php or elsewhere.'=>'The JETPACK_DEV_DEBUG constant is defined in wp-config.php or elsewhere.','In <a href="%s" target="_blank">Offline Mode</a>:'=>'In <a href="%s" target="_blank">Offline Mode</a>:','Invalid parameters.'=>'Invalid parameters.','Your plan doesn\'t include Pay with PayPal. <a href="%s" rel="noopener noreferrer" target="_blank">Learn more and upgrade</a>.'=>'Your plan doesn\'t include Pay with PayPal. <a href="%s" rel="noopener noreferrer" target="_blank">Learn more and upgrade</a>.','"yes" is a command - do not translate.Are you sure? This cannot be undone. Type "yes" to continue:'=>'Are you sure? This cannot be undone. Type "yes" to continue:','"yes" is a command - do not translate.Are you sure? Modifying this option may disrupt your Jetpack connection. Type "yes" to continue.'=>'Are you sure? Modifying this option may disrupt your Jetpack connection. Type "yes" to continue.','Are you sure you want to delete this item? It will be disabled and removed from all locations where it currently appears.'=>'Are you sure you want to delete this item? It will be disabled and removed from all locations where it currently appears.','Everything comes with a price tag these days. Please add a your product price.'=>'Everything comes with a price tag these days. Please add a product price.','People need to know what they\'re paying for! Please add a brief title.'=>'People need to know what they\'re paying for! Please add a brief title.','We want to make sure payments reach you, so please add an email address.'=>'We want to make sure payments reach you, so please add an email address.','(Only administrators will see this message.)'=>'(Only administrators will see this message.)','The Twitter Timeline widget can\'t display tweets based on searches or hashtags. To display a simple list of tweets instead, change the Widget ID to a Twitter username. Otherwise, delete this widget.'=>'The Twitter Timeline widget can\'t display tweets based on searches or hashtags. To display a simple list of tweets instead, change the Widget ID to a Twitter username. Otherwise, delete this widget.','Allow people to buy more than one item at a time.'=>'Allow people to buy more than one item at a time.','Delete Product'=>'Delete Product','Edit Selected'=>'Edit Selected','For example: event tickets, charitable donations, training courses, coaching fees, etc.'=>'For example: event tickets, charitable donations, training courses, coaching fees, etc.','Looks like you don\'t have any products. You can create one using the Add New button below.'=>'Looks like you don\'t have any products. You can create one using the Add New button below.','Product image'=>'Product image','Remove image'=>'Remove image','Select an image'=>'Select an image','This widget adds a payment button of your choice to your sidebar. To create or edit the payment buttons themselves, <a href="%s">use the Customizer</a>.'=>'This widget adds a payment button of your choice to your sidebar. To create or edit the payment buttons themselves, <a href="%s">use the Customiser</a>.','What is this payment for?'=>'What is this payment for?','Two-Step Authentication is required to access this site. Please visit your <a href="%1$s" rel="noopener noreferrer" target="_blank">Security Settings</a> to configure <a href="%2$s" rel="noopener noreferrer" target="_blank">Two-step Authentication</a> for your account.'=>'Two-Step Authentication is required to access this site. Please visit your <a href="%1$s" rel="noopener noreferrer" target="_blank">Security Settings</a> to configure <a href="%2$s" rel="noopener noreferrer" target="_blank">Two-step Authentication</a> for your account.','Widget Title'=>'Widget Title','Bottom'=>'Bottom','Navigation itemDebug'=>'Debug','Position'=>'Position','Navigation itemPrivacy'=>'Privacy','Navigation itemTerms'=>'Terms','Top'=>'Top','This is where PayPal will send your money. To claim a payment, you\'ll need a <a href="%1$s" %2$s>PayPal account</a> connected to a bank account.'=>'This is where PayPal will send your money. To claim a payment, you\'ll need a <a href="%1$s" %2$s>PayPal account</a> connected to a bank account.','This is an XML News Sitemap generated by <a href="%1$s" rel="noopener noreferrer" target="_blank">Jetpack</a>, meant to be consumed by search engines like <a href="%2$s" rel="noopener noreferrer" target="_blank">Google</a> or <a href="%3$s" rel="noopener noreferrer" target="_blank">Bing</a>.'=>'This is an XML News Sitemap generated by <a href="%1$s" rel="noopener noreferrer" target="_blank">Jetpack</a>, meant to be consumed by search engines like <a href="%2$s" rel="noopener noreferrer" target="_blank">Google</a> or <a href="%3$s" rel="noopener noreferrer" target="_blank">Bing</a>.','This is an XML Video Sitemap generated by <a href="%1$s" rel="noopener noreferrer" target="_blank">Jetpack</a>, meant to be consumed by search engines like <a href="%2$s" rel="noopener noreferrer" target="_blank">Google</a> or <a href="%3$s" rel="noopener noreferrer" target="_blank">Bing</a>.'=>'This is an XML Video Sitemap generated by <a href="%1$s" rel="noopener noreferrer" target="_blank">Jetpack</a>, meant to be consumed by search engines like <a href="%2$s" rel="noopener noreferrer" target="_blank">Google</a> or <a href="%3$s" rel="noopener noreferrer" target="_blank">Bing</a>.','This is an XML Image Sitemap generated by <a href="%1$s" rel="noopener noreferrer" target="_blank">Jetpack</a>, meant to be consumed by search engines like <a href="%2$s" rel="noopener noreferrer" target="_blank">Google</a> or <a href="%3$s" rel="noopener noreferrer" target="_blank">Bing</a>.'=>'This is an XML Image Sitemap generated by <a href="%1$s" rel="noopener noreferrer" target="_blank">Jetpack</a>, meant to be consumed by search engines like <a href="%2$s" rel="noopener noreferrer" target="_blank">Google</a> or <a href="%3$s" rel="noopener noreferrer" target="_blank">Bing</a>.','This is an XML Sitemap Index generated by <a href="%1$s" rel="noopener noreferrer" target="_blank">Jetpack</a>, meant to be consumed by search engines like <a href="%2$s" rel="noopener noreferrer" target="_blank">Google</a> or <a href="%3$s" rel="noopener noreferrer" target="_blank">Bing</a>.'=>'This is an XML Sitemap Index generated by <a href="%1$s" rel="noopener noreferrer" target="_blank">Jetpack</a>, meant to be consumed by search engines like <a href="%2$s" rel="noopener noreferrer" target="_blank">Google</a> or <a href="%3$s" rel="noopener noreferrer" target="_blank">Bing</a>.','Generated by <a href="%s" rel="noopener noreferrer" target="_blank">Jetpack for WordPress</a>'=>'Generated by <a href="%s" rel="noopener noreferrer" target="_blank">Jetpack for WordPress</a>','You can find more information on XML sitemaps at <a href="%1$s" rel="noopener noreferrer" target="_blank">sitemaps.org</a>'=>'You can find more information on XML sitemaps at <a href="%1$s" rel="noopener noreferrer" target="_blank">sitemaps.org</a>','This is an XML Sitemap generated by <a href="%1$s" rel="noopener noreferrer" target="_blank">Jetpack</a>, meant to be consumed by search engines like <a href="%2$s" rel="noopener noreferrer" target="_blank">Google</a> or <a href="%3$s" rel="noopener noreferrer" target="_blank">Bing</a>.'=>'This is an XML Sitemap generated by <a href="%1$s" rel="noopener noreferrer" target="_blank">Jetpack</a>, meant to be consumed by search engines like <a href="%2$s" rel="noopener noreferrer" target="_blank">Google</a> or <a href="%3$s" rel="noopener noreferrer" target="_blank">Bing</a>.','noun: a quantity of goods or items purchased or soldOrder'=>'Order','The WordAds module is not active'=>'The WordAds module is not active','Show a thumbnail image where available.'=>'Show a thumbnail image where available.','Unexpected hostname'=>'Unexpected hostname','Show photo metadata (<a href="https://en.wikipedia.org/wiki/Exchangeable_image_file_format" rel="noopener noreferrer" target="_blank">Exif</a>) in carousel, when available.'=>'Show photo metadata (<a href="https://en.wikipedia.org/wiki/Exchangeable_image_file_format" rel="noopener noreferrer" target="_blank">Exif</a>) in carousel, when available.','A connection ID must be passed in order to disconnect.'=>'A connection ID must be passed in order to disconnect.','Could not confirm new owner.'=>'Could not confirm new owner.','Disconnecting all connections to %s.'=>'Disconnecting all connections to %s.','New owner is not admin'=>'New owner is not admin','New owner is not connected'=>'New owner is not connected','All Jetpack Social connections to %s were successfully disconnected.'=>'All Jetpack Social connections to %s were successfully disconnected.','All Jetpack Social connections were successfully disconnected.'=>'All Jetpack Social connections were successfully disconnected.','You\'re about to delete all Jetpack Social connections to %s.'=>'You\'re about to delete all Jetpack Social connections to %s.','Highlight related content with a heading'=>'Highlight related content with a heading','View security scan details'=>'View security scan details','Show a thumbnail image where available'=>'Show a thumbnail image where available','actionCapture consent & hide the banner'=>'Capture consent & hide the banner','actionConsent expires after'=>'Consent expires after','Cookie Policy'=>'Cookie Policy','Cookies & Consents Banner'=>'Cookies & Consents Banner','Display a banner for EU Cookie Law and GDPR compliance.'=>'Display a banner for EU Cookie Law and GDPR compliance.','Link text'=>'Link text','For GDPR compliance, please make sure your policy contains <a href="%s" target="_blank">privacy information relating to WordAds</a>.'=>'For GDPR compliance, please make sure your policy contains <a href="%s" target="_blank">privacy information relating to WordAds</a>.','Visitors must provide consent by clicking the dismiss button when WordAds is turned on.'=>'Visitors must provide consent by clicking the dismiss button when WordAds is turned on.','Privacy & Cookies: This site uses cookies. By continuing to use this website, you agree to their use.

To find out more, including how to control cookies, see here:'=>'Privacy & Cookies: This site uses cookies. By continuing to use this website, you agree to their use.

To find out more, including how to control cookies, see here:','The default policy URL only covers cookies set by Jetpack. If you’re running other plugins, custom cookies, or third-party tracking technologies, you should create and link to your own cookie statement.'=>'The default policy URL only covers cookies set by Jetpack. If you’re running other plugins, custom cookies, or third-party tracking technologies, you should create and link to your own cookie statement.','Caution:'=>'Caution:','Custom URL:'=>'Custom URL:','Feedback ID %d could not be removed at this time.'=>'Feedback ID %d could not be removed at this time.','Privacy Policy Link'=>'Privacy Policy Link','Request to %1$s returned a non-200 response code: %2$d.'=>'Request to %1$s returned a non-200 response code: %2$d.','Request to %1$s returned an error: (%2$d) %3$s.'=>'Request to %1$s returned an error: (%2$d) %3$s.','Social Media Icons (Deprecated)'=>'Social Media Icons (Deprecated)','RSS Feed'=>'RSS Feed','Account URL'=>'Account URL','Open link in a new tab'=>'Open link in a new tab','View available icons'=>'View available icons','Add an icon'=>'Add an icon','Size:'=>'Size:','Follow Us'=>'Follow Us','Social Icons'=>'Social Icons','Add social-media icons to your site.'=>'Add social-media icons to your site.','UTC%s'=>'UTC%s','%1$s (%2$s)'=>'%1$s (%2$s)','Post published and sending emails to subscribers.'=>'Post published and sending emails to subscribers.','Post published and sharing on %1$s.'=>'Post published and sharing on %1$s.','Post published, sending emails to subscribers and sharing post on %1$s.'=>'Post published, sending emails to subscribers and sharing post on %1$s.','Project published and sharing project on %1$s.'=>'Project published and sharing project on %1$s.','View post'=>'View post','View project'=>'View project','You have already subscribed to this site. Please check your email inbox. You can manage your preferences from the <a href="%1$s" title="%2$s" target="_blank">Subscriptions Manager</a>.'=>'You have already subscribed to this site. Please check your email inbox. You can manage your preferences from the <a href="%1$s" title="%2$s" target="_blank">Subscriptions Manager</a>.','More %s'=>'More %s','Comment Form'=>'Comment Form','Only one embed can be rendered at a time.'=>'Only one embed can be rendered at a time.','The embed_url parameter must be a valid URL.'=>'The embed_url parameter must be a valid URL.','The requested URL is not an embed.'=>'The requested URL is not an embed.','Your token must have permission to post on this blog.'=>'Your token must have permission to post on this blog.','Could not activate %s'=>'Could not activate %s','Authorized %d and activated default modules.'=>'Authorised %d and activated default modules.','Authorized %d.'=>'Authorised %d.','%s could not be activated.'=>'%s could not be activated.','A non-empty token argument must be passed.'=>'A non-empty token argument must be passed.','Please select a user to authorize via the --user global argument.'=>'Please select a user to authorise via the --user global argument.','The requested Jetpack module is not supported by your plan.'=>'The requested Jetpack module is not supported by your plan.','The required "local_user" parameter is missing.'=>'The required "local_user" parameter is missing.','There was an issue validating this request.'=>'There was an issue validating this request.','Valid user is required'=>'Valid user is required','The required "%s" parameter is missing.'=>'The required "%s" parameter is missing.','Enhanced analytics for WooCommerce and Jetpack users.'=>'Enhanced analytics for WooCommerce and Jetpack users.','Cannot cancel a plan while in safe mode. See: https://jetpack.com/support/safe-mode/'=>'Cannot cancel a plan while in safe mode. See: https://jetpack.com/support/safe-mode/','Cannot provision a plan while in safe mode. See: https://jetpack.com/support/safe-mode/'=>'Cannot provision a plan while in safe mode. See: https://jetpack.com/support/safe-mode/','Unknown Plugin Update Failure'=>'Unknown Plugin Update Failure','Why aren\'t my filters appearing?'=>'Why aren\'t my filters appearing?','Adding filters requires JavaScript!'=>'Adding filters requires JavaScript!','Add a filter'=>'Add a filter','Maximum number of filters (1-50):'=>'Maximum number of filters (1-50):','A label for a taxonomy selector option%1$s (%2$s)'=>'%1$s (%2$s)','Default sort order:'=>'Default sort order:','Post types to search (minimum of 1):'=>'Post types to search (minimum of 1):','Show sort selection dropdown'=>'Show sort selection dropdown','Title (optional):'=>'Title (optional):','Oldest first'=>'Oldest first','Sort by'=>'Sort by','Newest first'=>'Newest first','Relevance'=>'Relevance','Relevance (recommended)'=>'Relevance (recommended)','< Clear Filters'=>'< Clear Filters','label for filtering postsMonth'=>'Month','label for filtering postsPost Types'=>'Post Types','label for filtering postsYear Updated'=>'Year Updated','label for filtering postsMonth Updated'=>'Month Updated','label for filtering postsYear'=>'Year','Jetpack will optimize your images and serve them from the server location nearest
		to your visitors. Using our global content delivery network will boost the loading speed of your site.'=>'Jetpack will optimise your images and serve them from the server location nearest
		to your visitors. Using our global content delivery network will boost the loading speed of your site.','You are not allowed to install plugins on this site.'=>'You are not allowed to install plugins on this site.','You are not allowed to activate plugins on this site.'=>'You are not allowed to activate plugins on this site.','Primary language for the site.'=>'Primary language for the site.','Set up Jetpack'=>'Set up Jetpack','label for formatting JSONMinify'=>'Minify','label for formatting JSONPretty'=>'Pretty','Text displayed when there is no informationNone'=>'None','Last query information:'=>'Last query information:','Jetpack Search'=>'Jetpack Search','displayed in search results when results are cachedcache hit'=>'cache hit','Remove'=>'Remove','Choose an interval:'=>'Choose an interval:','Modified GMT'=>'Modified GMT','Modified'=>'Modified','Date GMT'=>'Date GMT','Choose a field:'=>'Choose a field:','Choose a taxonomy:'=>'Choose a taxonomy:','Post Type'=>'Post Type','Taxonomy'=>'Taxonomy','Filter Type:'=>'Filter Type:','Show search box'=>'Show search box','%s Get help unlocking your site'=>'%s Get help unlocking your site','%s Back'=>'%s Back','Send email'=>'Send email','Your email'=>'Your email','<p>Your IP address <code>%2$s</code> has been flagged for potential security violations. You can unlock your login by sending yourself a special link via email. <a href="%3$s">Learn More</a></p>'=>'<p>Your IP address <code>%2$s</code> has been flagged for potential security violations. You can unlock your login by sending yourself a special link via email. <a href="%3$s">Learn More</a></p>','Oops, we were unable to send a recovery email. Try again.'=>'Oops, we were unable to send a recovery email. Try again.','Recovery instructions were sent to %s. Check your inbox!'=>'Recovery instructions were sent to %s. Check your inbox!','Oops, we couldn\'t find a user with that email. Please try again!'=>'Oops, we couldn\'t find a user with that email. Please try again!','Oops, we couldn\'t validate the recovery token.'=>'Oops, we couldn\'t validate the recovery token.','Failed fetching rewind data. Try again later.'=>'Failed fetching rewind data. Try again later.','Oops, looks like that\'s not the right email address. Please try again!'=>'Oops, looks like that\'s not the right email address. Please try again!','You successfully logged out.'=>'You successfully logged out.','The recovery token is not valid for this user.'=>'The recovery token is not valid for this user.','Jetpack has locked your site\'s login page.'=>'Jetpack has locked your site\'s login page.','Jetpack Sitemaps module is active, but unavailable. This can happen if your site is set to discourage search engine indexing. Please enable search engine indexing to allow sitemap generation.'=>'Jetpack Sitemaps module is active, but unavailable. This can happen if your site is set to discourage search engine indexing. Please enable search engine indexing to allow sitemap generation.','Jetpack Sitemaps module is not currently active. Activate it first if you want to work with sitemaps.'=>'Jetpack Sitemaps module is not currently active. Activate it first if you want to work with sitemaps.','Resetting Jetpack Options for %s...
'=>'Resetting Jetpack Options for %s...
','Testing connection for %s'=>'Testing connection for %s','Checking status for %s'=>'Checking status for %s','Milestone widget: mode in which the date unit is set to hoursHours'=>'Hours','Milestone widget: mode in which the date unit is set to daysDays'=>'Days','Milestone widget: mode in which the date unit is set to monthsMonths'=>'Months','Milestone widget: mode in which the date unit is set to yearsYears'=>'Years','Milestone widget: mode in which the date unit is determined automaticallyAutomatic'=>'Automatic','<span class="difference">%s</span> <span class="label">second to go.</span>'=>'<span class="difference">%s</span> <span class="label">second to go.</span>' . "\0" . '<span class="difference">%s</span> <span class="label">seconds to go.</span>','<span class="difference">%s</span> <span class="label">minute to go.</span>'=>'<span class="difference">%s</span> <span class="label">minute to go.</span>' . "\0" . '<span class="difference">%s</span> <span class="label">minutes to go.</span>','<span class="difference">%s</span> <span class="label">hour to go.</span>'=>'<span class="difference">%s</span> <span class="label">hour to go.</span>' . "\0" . '<span class="difference">%s</span> <span class="label">hours to go.</span>','<span class="difference">%s</span> <span class="label">day to go.</span>'=>'<span class="difference">%s</span> <span class="label">day to go.</span>' . "\0" . '<span class="difference">%s</span> <span class="label">days to go.</span>','<span class="difference">%s</span> <span class="label">month to go.</span>'=>'<span class="difference">%s</span> <span class="label">month to go.</span>' . "\0" . '<span class="difference">%s</span> <span class="label">months to go.</span>','<span class="difference">%s</span> <span class="label">year to go.</span>'=>'<span class="difference">%s</span> <span class="label">year to go.</span>' . "\0" . '<span class="difference">%s</span> <span class="label">years to go.</span>','<span class="difference">%s</span> <span class="label">second ago.</span>'=>'<span class="difference">%s</span> <span class="label">second ago.</span>' . "\0" . '<span class="difference">%s</span> <span class="label">seconds ago.</span>','<span class="difference">%s</span> <span class="label">minute ago.</span>'=>'<span class="difference">%s</span> <span class="label">minute ago.</span>' . "\0" . '<span class="difference">%s</span> <span class="label">minutes ago.</span>','<span class="difference">%s</span> <span class="label">hour ago.</span>'=>'<span class="difference">%s</span> <span class="label">hour ago.</span>' . "\0" . '<span class="difference">%s</span> <span class="label">hours ago.</span>','<span class="difference">%s</span> <span class="label">day ago.</span>'=>'<span class="difference">%s</span> <span class="label">day ago.</span>' . "\0" . '<span class="difference">%s</span> <span class="label">days ago.</span>','<span class="difference">%s</span> <span class="label">month ago.</span>'=>'<span class="difference">%s</span> <span class="label">month ago.</span>' . "\0" . '<span class="difference">%s</span> <span class="label">months ago.</span>','<span class="difference">%s</span> <span class="label">year ago.</span>'=>'<span class="difference">%s</span> <span class="label">year ago.</span>' . "\0" . '<span class="difference">%s</span> <span class="label">years ago.</span>','Type of gallery.'=>'Type of gallery.','Sorry, you are not allowed to deactivate this plugin.'=>'Sorry, you are not allowed to deactivate this plugin.','Sorry, you are not allowed to activate this plugin.'=>'Sorry, you are not allowed to activate this plugin.','Plugin deactivation is not allowed'=>'Plugin deactivation is not allowed','The site is not the main network site'=>'The site is not the main network site','Multi network install are not supported.'=>'Multi network install are not supported.','Any autoupdates are explicitly disabled by a site administrator.'=>'Any auto updates are explicitly disabled by a site administrator.','File modifications are explicitly disabled by a site administrator.'=>'File modifications are explicitly disabled by a site administrator.','The file permissions on this host prevent editing files.'=>'The file permissions on this host prevent editing files.','You cannot delete a plugin while it is active on the main site.'=>'You cannot delete a plugin while it is active on the main site.','The requested widget was not found.'=>'The requested widget was not found.','Milestone Reached Message'=>'Milestone Reached Message','Since your milestone'=>'Since your milestone','Until your milestone'=>'Until your milestone','Time Unit'=>'Time Unit','Continue reading<span class="screen-reader-text"> "%s"</span>'=>'Continue reading<span class="screen-reader-text"> "%s"</span>','Display on single projects'=>'Display on single projects','Learn more about Featured Images'=>'Learn more about Featured Images','Simple Payments products'=>'Simple Payments products','Product'=>'Product','Simple Payments orders'=>'Simple Payments orders','Automatically use first image in post'=>'Automatically use first image in post','Display comment link'=>'Display comment link','recipeSource'=>'Source','PHP’s XML extension is not available. Please contact your hosting provider to enable PHP’s XML extension.'=>'PHP\'s XML extension is not available. Please contact your hosting provider to enable PHP\'s XML extension.','Update Form'=>'Update Form','Add Field'=>'Add Field','Contact form fields'=>'Contact form fields','What would you like the subject of the email to be?'=>'What would you like the subject of the email to be?','Contact form information'=>'Contact form information','Delete Field'=>'Delete Field','Add new option...'=>'Add new option...','Delete Option'=>'Delete Option','Field Type'=>'Field Type','Field Label'=>'Field Label','Form Field'=>'Form Field','Add contact form'=>'Add contact form','contact form'=>'contact form','Are you sure you\'d like to stop editing this form without saving your changes?'=>'Are you sure you\'d like to stop editing this form without saving your changes?','Module NameComment Likes'=>'Comment Likes','User not found'=>'User not found','You must specify a User ID'=>'You must specify a User ID','Term not found'=>'Term not found','You must specify a Term ID'=>'You must specify a Term ID','You must specify an option name'=>'You must specify an option name','Comment not found'=>'Comment not found','You must specify a Comment ID'=>'You must specify a Comment ID','Module NameSearch'=>'Search','user login is required'=>'user login is required','user email is required'=>'user email is required','user_data is required'=>'user_data is required','user_token is required'=>'user_token is required','The user is already connected'=>'The user is already connected','user_id is required'=>'user_id is required','%s is not a valid role.'=>'%s is not a valid role.','The roles property must be a string or an array.'=>'The roles property must be a string or an array.','Which email address should we send the responses to?'=>'Which email address should we send the responses to?','Failed to test connection (empty response body)'=>'Failed to test connection (empty response body)','Failed to test connection (#%1$s: %2$s)'=>'Failed to test connection (#%1$s: %2$s)','Sync errored with code: %s'=>'Sync errored with code: %s','Request failed with code %s'=>'Request failed with code %s','There was an unspecified error registering the site'=>'There was an unspecified error registering the site','Missing or invalid access token'=>'Missing or invalid access token','Invalid token JSON: %s'=>'Invalid token JSON: %s','Your site is not connected to Jetpack.'=>'Your site is not connected to Jetpack.','Display ads on archive pages?'=>'Display ads on archive pages?','Display ads on pages?'=>'Display ads on pages?','Display ads on posts?'=>'Display ads on posts?','Display ads on the front page?'=>'Display ads on the front page?','Display second ad below post?'=>'Display second ad below post?','Site features correctly received.'=>'Site features correctly received.','Unable to fetch the requested data.'=>'Unable to fetch the requested data.','Could not connect to VaultPress.'=>'Could not connect to VaultPress.','The WordPress.com account for the primary connection is %s'=>'The WordPress.com account for the primary connection is %s','the Internet Defense LeagueLearn more about the %s'=>'Learn more about the %s','Which badge would you like to display?'=>'Which badge would you like to display?','Member of The Internet Defense League'=>'Member of The Internet Defence League','Red Cat Badge'=>'Red Cat Badge','Super Badge'=>'Super Badge','Shield Badge'=>'Shield Badge','Show your support for the Internet Defense League.'=>'Show your support for the Internet Defence League.','Internet Defense League'=>'Internet Defence League','Flickr Photos'=>'Flickr Photos','Display your recent Flickr photos.'=>'Display your recent Flickr photos.','Flickr'=>'Flickr','More Photos'=>'More Photos','What size photos would you like to display?'=>'What size photos would you like to display?','How many photos would you like to display?'=>'How many photos would you like to display?','Leave the Flickr RSS URL field blank to display <a target="_blank" href="%s">interesting</a> Flickr photos.'=>'Leave the Flickr RSS URL field blank to display <a target="_blank" href="%s">interesting</a> Flickr photos.','(Only admins can see this message)'=>'(Only admins can see this message)','There are no photos to display. Make sure your Flickr feed URL is correct, and that your pictures are publicly accessible.'=>'There are no photos to display. Make sure your Flickr feed URL is correct, and that your pictures are publicly accessible.','To find your Flickr RSS URL, go to your photostream, add "?details=1" to the URL, and hit enter. Scroll down until you see the RSS icon or the "Latest" link. Right-click on either options and copy the URL. Paste into the box above.'=>'To find your Flickr RSS URL, go to your photostream, add "?details=1" to the URL, and hit Enter. Scroll down until you see the RSS icon or the "Latest" link. Right-click on either options and copy the URL. Paste into the box above.','Flickr RSS URL:'=>'Flickr RSS URL:','Close and accept'=>'Close and accept','Click here for more information'=>'Click here for more information','It is your own responsibility to ensure that your site complies with the relevant laws.'=>'It is your own responsibility to ensure that your site complies with the relevant laws.','Button text'=>'Button text','Custom:'=>'Custom:','Banner text'=>'Banner text','after this amount of time'=>'after this amount of time','after the user scrolls the page'=>'after the user scrolls the page','after the user clicks the dismiss button'=>'after the user clicks the dismiss button','Sitemaps'=>'Sitemaps','Code: <a href="%s" target="_blank">( ? )</a>'=>'Code: <a href="%s" target="_blank">( ? )</a>','Allows displaying a popup subscription form to visitors.'=>'Allows displaying a popup subscription form to visitors.','MailChimp Subscriber Popup'=>'MailChimp Subscriber Popup','Also display tagged posts outside the Featured Content area.'=>'Also display tagged posts outside the Featured Content area.','Do not display tag in post details and tag clouds.'=>'Do not display tag in post details and tag clouds.','Word count type. Do not translate!words'=>'words','Sitemap Interval'=>'Sitemap Interval','Publication Date'=>'Publication Date','XML News Sitemap'=>'XML News Sitemap','Video URL'=>'Video URL','XML Video Sitemap'=>'XML Video Sitemap','Image URL'=>'Image URL','Page URL'=>'Page URL','XML Image Sitemap'=>'XML Image Sitemap','Sitemap URL'=>'Sitemap URL','XML Sitemap Index'=>'XML Sitemap Index','Module DescriptionDisplay different types of content on your site with custom content types.'=>'Display different types of content on your site with custom content types.','Module NameWordPress.com Reader'=>'WordPress.com Reader','Plan'=>'Plan','Help'=>'Help','Manage Purchases'=>'Manage Purchases','Reader'=>'Reader','Access the full list of Jetpack modules available on your site.'=>'Access the full list of Jetpack modules available on your site.','More details about your Jetpack settings'=>'More details about your Jetpack settings','Jetpack works by connecting to WordPress.com for a lot of features. Sometimes, when the connection gets messed up, you need to disconnect and reconnect to get things working properly. <a href="%s">Disconnect from WordPress.com</a>'=>'Jetpack works by connecting to WordPress.com for a lot of features. Sometimes, when the connection gets messed up, you need to disconnect and reconnect to get things working properly. <a href="%s">Disconnect from WordPress.com</a>','Log out'=>'Log out','A connection problem with WordPress.com.'=>'A connection problem with WordPress.com.','%1$s: %2$s'=>'%1$s: %2$s','Akismet is not installed or active'=>'Akismet is not installed or active','Invalid Akismet key'=>'Invalid Akismet key','Invalid Akismet user'=>'Invalid Akismet user','Akismet user status doesn\'t allow to update the key'=>'Akismet user status doesn\'t allow to update the key','%s must be an alphanumeric string or a verification tag.'=>'%s must be an alphanumeric string or a verification tag.','Color scheme.'=>'Colour scheme.','Error fetching static.html. Try running: '=>'Error fetching static.html. Try running: ','An Automattic Airline'=>'An Automattic Airline','Priority support'=>'Priority support','Color scheme'=>'Colour scheme','Post type Archives:'=>'Post type Archives:','Match all conditions'=>'Match all conditions','Shown between widget visibility conditions.and'=>'and','Checkbox on Widget Visibility if children of the selected page should be included in the visibility rule.Include children'=>'Include children','Cleaned up %d video.'=>'Cleaned up %d video.' . "\0" . 'Cleaned up a total of %d videos.','Social Links Menu'=>'Social Links Menu','Please define an SVG icon filename.'=>'Please define an SVG icon filename.','Please define default parameters in the form of an array.'=>'Please define default parameters in the form of an array.','No stats'=>'No stats','Copyright'=>'Copyright','Site ID must be provided to disconnect a sub-site.'=>'Site ID must be provided to disconnect a sub-site.','Site ID must be provided to register a sub-site.'=>'Site ID must be provided to register a sub-site.','View'=>'View','New free service: Show Canada Post shipping rates on your store!'=>'New free service: Show Canada Post shipping rates on your store!','New free service: Show USPS shipping rates on your store! Added bonus: print shipping labels without leaving WooCommerce.'=>'New free service: Show USPS shipping rates on your store! Added bonus: print shipping labels without leaving WooCommerce.','Sorry, you are not allowed to preview drafts.'=>'Sorry, you are not allowed to preview drafts.','Use Markdown for posts.'=>'Use Markdown for posts.','Track each scroll load (7 posts by default) as a page view in Google Analytics'=>'Track each scroll load (7 posts by default) as a page view in Google Analytics','Advertisements'=>'Advertisements','Jetpack is not connected. Please connect Jetpack by visiting <a href=\'%s\'>Settings</a>.'=>'Jetpack is not connected. Please connect Jetpack by visiting <a href=\'%s\'>Settings</a>.','Post not found'=>'Post not found','You must specify a Post ID'=>'You must specify a Post ID','Nothing is in the queue: %s'=>'Nothing is in the queue: %s','Google Analytics'=>'Google Analytics','Track website statistics with Google Analytics for a deeper understanding of your website visitors and customers.'=>'Track website statistics with Google Analytics for a deeper understanding of your website visitors and customers.','There was an error installing WooCommerce Services.'=>'There was an error installing WooCommerce Services.','Width in pixels'=>'Width in pixels','It looks like the WordPress site URL is incorrectly configured. Please check it in your widget settings.'=>'It looks like the WordPress site URL is incorrectly configured. Please check it in your widget settings.','Items to show:'=>'Items to show:','iCalendar Feed URL:'=>'iCalendar Feed URL:','Display upcoming events from an iCalendar feed.'=>'Display upcoming events from an iCalendar feed.','Upcoming Events'=>'Upcoming Events','Height in pixels:'=>'Height in pixels:','Image missing or invalid URL. Please check the Image widget URL in your <a href="%s">widget settings</a>.'=>'Image missing or invalid URL. Please check the Image widget URL in your <a href="%s">widget settings</a>.','Height in pixels'=>'Height in pixels','Maximum: %s'=>'Maximum: %s','Minimum: %s'=>'Minimum: %s','Contact Info & Map'=>'Contact Info & Map','Tag Dimensions:'=>'Tag Dimensions:','Insert an ad unit wherever you can place a widget.'=>'Insert an ad unit wherever you can place a widget.','Error connecting to API.'=>'Error connecting to API.','Minutes'=>'Minutes','Hour'=>'Hour','Year'=>'Year','Day'=>'Day','Month'=>'Month','The big day is here.'=>'The big day is here.','The Big Day'=>'The Big Day','days'=>'days','year'=>'year','Milestone'=>'Milestone','Display a countdown to a certain date.'=>'Display a countdown to a certain date.','Translate'=>'Translate','Provide your readers with the option to translate your site into their preferred language.'=>'Provide your readers with the option to translate your site into their preferred language.','Width in pixels:'=>'Width in pixels:','The Blog URL is not properly set up in the widget.'=>'The Blog URL is not properly set up in the widget.','No upcoming events'=>'No upcoming events','The Blip.tv service has been shut down since August 20th, 2015.'=>'The Blip.tv service has been shut down since August 20th, 2015.','hits'=>'hits','Blog Stats'=>'Blog Stats','Show a hit counter for your blog.'=>'Show a hit counter for your blog.','No Avatars'=>'No Avatars','Avatar Size (px):'=>'Avatar Size (px):','(at most 10)'=>'(at most 10)','Number of posts to show for each author:'=>'Number of posts to show for each author:','Display all authors (including those who have not written any posts)'=>'Display all authors (including those who have not written any posts)','Display blogs authors with avatars and recent posts.'=>'Display blogs authors with avatars and recent posts.','Authors'=>'Authors','Display on pages'=>'Display on pages','Display on blog and archives'=>'Display on blog and archives','Display author'=>'Display author','Display tags'=>'Display tags','Display categories'=>'Display categories','Display date'=>'Display date','Post Details'=>'Post Details','Display on single posts'=>'Display on single posts','Author Bio'=>'Author Bio','Blog Display'=>'Blog Display','Choose between a full post or an excerpt for the blog and archive pages.'=>'Choose between a full post or an excerpt for the blog and archive pages.','Choose between a full post or an excerpt for the blog and archive pages, or opt for the theme\'s default combination of excerpt and full post.'=>'Choose between a full post or an excerpt for the blog and archive pages, or opt for the theme\'s default combination of excerpt and full post.','Post excerpt'=>'Post excerpt','Full post'=>'Full post','Content Options'=>'Content Options','There is no excerpt because this is a protected post.'=>'There is no excerpt because this is a protected post.','View all posts by %s'=>'View all posts by %s','Published by %s'=>'Published by %s','Please view this post in your web browser to complete the quiz.'=>'Please view this post in your web browser to complete the quiz.','View complete profile'=>'View complete profile','Bio:'=>'Bio:','<code>%s</code> HTML tag removed as it is not allowed'=>'<code>%s</code> HTML tag removed as it is not allowed','Weddings are in the spotlight now with VideoPress for weddings.'=>'Weddings are in the spotlight now with VideoPress for weddings.','Writing is new again in Android with the new WordPress app.'=>'Writing is new again in Android with the new WordPress app.','In "Mobile"'=>'In "Mobile"','It is that time of the year when devices are shiny again.'=>'It is that time of the year when devices are shiny again.','Show context (category or tag)'=>'Show context (category or tag)','Show entry date'=>'Show entry date','Please note that the related posts displayed now are only for previewing purposes.'=>'Please note that the related posts displayed now are only for previewing purposes.','Upgrade Focus, VideoPress for weddings'=>'Upgrade Focus, VideoPress for weddings','Hit counter is delayed by up to 5 minutes.'=>'Hit counter is delayed by up to five minutes.','Please visit a single post view to reveal the customization options.'=>'Please visit a single post view to reveal the customisation options.','Arrange entries in different layouts.'=>'Arrange entries in different layouts.','Display entry\'s category or tag.'=>'Display entry\'s category or tag.','Show context'=>'Show context','Display date when entry was published.'=>'Display date when entry was published.','List'=>'List','Grid'=>'Grid','Show date'=>'Show date','Show thumbnails'=>'Show thumbnails','Enter text to use as headline.'=>'Enter text to use as headline.','This helps to clearly separate the related posts from post content.'=>'This helps to clearly separate the related posts from post content.','Show a headline'=>'Show a headline','Module NameAds'=>'Ads','The request is not signed correctly.'=>'The request is not signed correctly.','This request method does not support body parameters.'=>'This request method does not support body parameters.','This request method is not supported.'=>'This request method is not supported.','PHP\'s XML extension is not available. Jetpack requires the XML extension to communicate with WordPress.com. Please contact your hosting provider to enable PHP\'s XML extension.'=>'PHP\'s XML extension is not available. Jetpack requires the XML extension to communicate with WordPress.com. Please contact your hosting provider to enable PHP\'s XML extension.','Finished syncing to WordPress.com'=>'Finished syncing to WordPress.com','Sent more data to WordPress.com'=>'Sent more data to WordPress.com','Sent data to WordPress.com'=>'Sent data to WordPress.com','Could not start a new full sync'=>'Could not start a new full sync','Could not start a new full sync with modules: %s'=>'Could not start a new full sync with modules: %s','Initialized a new full sync'=>'Initialised a new full sync','Jetpack sync is not currently allowed for this site.'=>'Jetpack sync is not currently allowed for this site.','%1$s &ndash; %2$s'=>'%1$s &ndash; %2$s','Summary'=>'Summary','When'=>'When','Location'=>'Location','Display an ad unit at the top of each page.'=>'Display an ad unit at the top of each page.','Is site approved for WordAds?'=>'Is site approved for WordAds?','Initialized a new full sync with modules: %s'=>'Initialised a new full sync with modules: %s','By default ads are shown at the end of every page, post, or the first article on your front page. You can also add them to the top of your site and to any widget area to increase your earnings!'=>'By default ads are shown at the end of every page, post, or the first article on your front page. You can also add them to the top of your site and to any widget area to increase your earnings!','Video Hosting'=>'Video Hosting','Enable WordPress REST API to unlock Jetpack\'s full potential!'=>'Enable WordPress REST API to unlock Jetpack\'s full potential!','WordPress REST API is disabled'=>'WordPress REST API is disabled','Sync has been blocked from WordPress.com because it would cause an identity crisis'=>'Sync has been blocked from WordPress.com because it would cause an identity crisis','I\'m just starting out; leave me a comment or a like :)'=>'I\'m just starting out; leave me a comment or a like :)','There are no users to display in this <a href="%1$s">My Community widget</a>. <a href="%2$s">Want more traffic?</a>'=>'There are no users to display in this <a href="%1$s">My Community widget</a>. <a href="%2$s">Want more traffic?</a>','Include activity from commenters'=>'Include activity from commenters','Include activity from followers'=>'Include activity from followers','Include activity from likers'=>'Include activity from likers','Community'=>'Community','My Community'=>'My Community','Google Translate'=>'Google Translate','A header for the video rating areaRating'=>'Rating','A header for the video sharing options areaShare'=>'Share','A header for the shortcode displayShortcode'=>'Shortcode','A header for the short description displayDescription'=>'Description','Title will appear on the first frame of your video'=>'Title will appear on the first frame of your video','There was an issue saving your updates to the VideoPress service. Please try again later.'=>'There was an issue saving your updates to the VideoPress service. Please try again later.','VideoPress Information'=>'VideoPress Information','The cron named `%s` was removed from the schedule.'=>'The cron named `%s` was removed from the schedule.','The cron named `%s` was scheduled.'=>'The cron named `%s` was scheduled.','Cron will run at: %s GMT'=>'Cron will run at: %s GMT','The cron is not scheduled to run.'=>'The cron is not scheduled to run.','There is no cron named %s.'=>'There is no cron named %s.','You need to provide the name of the cronjob to schedule.'=>'You need to provide the name of the cron job to schedule.','Found no available cron jobs.'=>'Found no available cron jobs.','Status updated'=>'Status updated','A valid post_id is required.'=>'A valid post_id is required.','Every %d minutes'=>'Every %d minutes','50 community members'=>'50 community members','10 community members'=>'10 community members','Show a maximum of'=>'Show a maximum of','Display members of your site\'s community.'=>'Display members of your site\'s community.','That post does not have a VideoPress video associated to it.'=>'That post does not have a VideoPress video associated to it.','Found %d available cron job.'=>'Found %d available cron job.' . "\0" . 'Found %d available cron jobs.','Sorry, that Pinterest URL was not recognized.'=>'Sorry, that Pinterest URL was not recognised.','Posts about Category written by John and BobPosts about %1$s written by %2$l'=>'Posts about %1$s written by %2$l','Read all of the posts by Author Name on Blog TitleRead all of the posts by %1$s on %2$s'=>'Read all of the posts by %1$s on %2$s','Better results on search engines and social media.'=>'Better results on search engines and social media.','Sorry, you cannot view this resource.'=>'Sorry, you cannot view this resource.','Problem downloading theme'=>'Problem downloading theme','Problem creating file for theme download'=>'Problem creating file for theme download','This theme does not exist'=>'This theme does not exist','Invalid SEO title format.'=>'Invalid SEO title format.','Invalid SEO meta description value.'=>'Invalid SEO meta description value.','SEO tools are not enabled for this site.'=>'SEO tools are not enabled for this site.','Cannot parse URL %s'=>'Cannot parse URL %s','Module NameSEO Tools'=>'SEO Tools','Jetpack Safe Mode'=>'Jetpack Safe Mode','Would you like to use Jetpack on your local development site? You can do so thanks to <a href="%s">Jetpack\'s offline mode</a>.'=>'Would you like to use Jetpack on your local development site? You can do so thanks to <a href="%s">Jetpack\'s offline mode</a>.','Your site URL is set as `%1$s`, but your WordPress.com connection lists it as `%2$s`.'=>'Your site URL is set as `%1$s`, but your WordPress.com connection lists it as `%2$s`.','Invalid option: %s.'=>'Invalid option: %s.' . "\0" . 'Invalid options: %s.','The requested Jetpack data updates were successful.'=>'The requested Jetpack data updates were successful.','Yandex Site Verification'=>'Yandex Site Verification','Could not confirm migration.'=>'Could not confirm migration.','Could not delete sync error option.'=>'Could not delete sync error option.','Could not confirm safe mode.'=>'Could not confirm safe mode.','%s must be an array of post types.'=>'%s must be an array of post types.','There was an error creating a user for you. Please contact the administrator of your site.'=>'There was an error creating a user for you. Please contact the administrator of your site.','There was an error logging you in via WordPress.com, please try again or try logging in with your username and password.'=>'There was an error logging you in via WordPress.com, please try again or try logging in with your username and password.','Logging in with WordPress.com is not currently available because this site is experiencing connection problems.'=>'Logging in with WordPress.com is not currently available because this site is experiencing connection problems.','Your current IP: %1$s'=>'Your current IP: %1$s','Invalid parameter "dismissed".'=>'Invalid parameter "dismissed".','Automatically create two sitemap files that list the URLs of posts and pages in your site.
		This makes it easier for search engines (like Google) to include your site in relevant search results.'=>'Automatically create two sitemap files that list the URLs of posts and pages in your site.
		This makes it easier for search engines (like Google) to include your site in relevant search results.','Manage and update this and other WordPress sites from one simple dashboard on WordPress.com. You can update
		plugins, set them to automatically update, and (de)activate them on a per-site basis or in bulk from
		wordpress.com/plugins. You can also use the brand new and mobile-friendly post editor on WordPress.com as well
		as view and activate installed themes and create or edit site menus.'=>'Manage and update this and other WordPress sites from one simple dashboard on WordPress.com. You can update
		plugins, set them to automatically update, and (de)activate them on a per-site basis or in bulk from
		wordpress.com/plugins. You can also use the brand new and mobile-friendly post editor on WordPress.com, as well
		as view and activate installed themes, and create or edit site menus.','Add and organize content that doesn’t necessarily fit into a post or static page such as portfolios
		or testimonials. Custom	content can be visible at specific URLs, or you may add them with shortcodes.'=>'Add and organise content that doesn’t necessarily fit into a post or static page such as portfolios
		or testimonials. Custom	content can be visible at specific URLs, or you may add them with shortcodes.','Compose posts and comments with links, lists, and other styles using regular characters and
		punctuation marks. A quick and easy way to format text without needing any HTML or coding.'=>'Compose posts and comments with links, lists, and other styles using regular characters and
		punctuation marks. A quick and easy way to format text without needing any HTML or coding.','Verify your site ownership with services like Google, Bing, Pinterest, Yandex, and Facebook. This gives you access to
		advanced features on these services and get verification badges.'=>'Verify your site ownership with services like Google, Bing, Pinterest, Yandex, and Facebook. This gives you access to
		advanced features on these services and to get verification badges.','Show visitors related content from your site at the bottom of your posts. This encourages them
		to browse more content, explore your site, and transform them into regular readers.'=>'Show visitors related content from your site at the bottom of your posts. This encourages them
		to browse more content, explore your site, and transform them into regular readers.','Jetpack checks your site every five minutes and if any downtime is detected you will receive an email
		notification alerting you to the issue, so you can act quickly and get your site back online.'=>'Jetpack checks your site every five minutes and if any downtime is detected you will receive an email
		notification alerting you to the issue, so you can act quickly and get your site back online.','Your users will be able to log in to your site with their WordPress.com account.
		This includes two-factor authentication making it the safest login mechanism for your site.'=>'Your users will be able to log in to your site with their WordPress.com account.
		This includes two-factor authentication making it the safest login mechanism for your site.','The easiest way to upload ad-free and unbranded videos to your site. You get stats on video
		playback and shares and the player is lightweight and responsive.'=>'The easiest way to upload ad-free and unbranded videos to your site. You get stats on video
		playback and shares and the player is lightweight and responsive.','Choose from a set of visibility options for sidebar widgets such as showing them only certain categories,
		only on error pages, or only search results pages. You can also do the reverse and choose to hide them on certain pages.'=>'Choose from a set of visibility options for sidebar widgets such as showing them only certain categories,
		only on error pages, or only search results pages. You can also do the reverse and choose to hide them on certain pages.','Allow your readers to show their appreciation for your posts and other content. Likes show up
		below each post and your readers will also be able to review their liked posts from WordPress.com.'=>'Allow your readers to show their appreciation for your posts and other content. Likes show up
		below each post and your readers will also be able to review their liked posts from WordPress.com.','When adding an image gallery, you will have the option to create elegant magazine-style mosaic layouts for your photos,
		including mosaic (default), square, and circular layouts.'=>'When adding an image gallery, you will have the option to create elegant magazine-style mosaic layouts for your photos,
		including mosaic (default), square, and circular layouts.','Publish posts on your site by writing and sending an email from any email client instead of using the post editor.'=>'Publish posts on your site by writing and sending an email from any email client instead of using the post editor.','Infinite scrolling pulls the next set of posts automatically into view when the reader approaches
		the bottom of the page. This helps you reader see more of your content.'=>'Infinite scrolling pulls the next set of posts automatically into view when the reader approaches
		the bottom of the page. This helps you reader see more of your content.','Allow visitors to use their WordPress.com or Facebook accounts when commenting on
		your site. Jetpack will match your site\'s color scheme automatically (but you can adjust that).'=>'Allow visitors to use their WordPress.com or Facebook accounts when commenting on
		your site. Jetpack will match your site\'s colour scheme automatically (but you can adjust that).','Create simple contact forms without any coding. You can have multiple forms and when
		a user submits it, their feedback will be emailed directly to you. If Akismet is active, submissions will be
		automatically filtered for spam.'=>'Create simple contact forms without any coding. You can have multiple forms and when
		a user submits it, their feedback will be emailed directly to you. If Akismet is active, submissions will be
		automatically filtered for spam.','Authorize applications and services to securely connect to your site. Developers can use WordPress.com\'s OAuth2
		authentication system and WordPress.com REST API to manage and access your site\'s content.'=>'Authorise applications and services to securely connect to your site. Developers can use WordPress.com\'s OAuth2
		authentication system and WordPress.com REST API to manage and access your site\'s content.','Most sites will come under attack from automated bots that attempt to log in for malicious purposes.
		We protect you automatically from unauthorized access by using data from millions of sites.'=>'Most sites will come under attack from automated bots that attempt to log in for malicious purposes.
		We protect you automatically from unauthorised access by using data from millions of sites.','A widget in your sidebar allows visitors to subscribe to your site so that they receive an email
		each time you publish new content. Your visitors can also subscribe to a post\'s comments to keep up with the conversation.'=>'A widget in your sidebar allows visitors to subscribe to your site so that they receive an email
		each time you publish new content. Your visitors can also subscribe to a post\'s comments to keep up with the conversation.','Add as many custom widgets as you like by dragging and dropping and customize each to fit your needs,
		including, Twitter streams, Facebook like boxes, custom images, Gravatars, tiled galleries, recent posts,
		or social icons.'=>'Add as many custom widgets as you like by dragging and dropping and customise each to fit your needs,
		including, Twitter streams, Facebook \'like\' boxes, custom images, Gravatars, tiled galleries, recent posts,
		or social icons.','Visitors can share your posts with Twitter, Facebook, Reddit, Digg, LinkedIn, print,
		and email. You can configure services to appear as icons, text, or both and some services like Twitter
		have additional options.'=>'Visitors can share your posts with Twitter, Facebook, Reddit, Digg, LinkedIn, print,
		and email. You can configure services to appear as icons, text, or both, and some services like Twitter
		have additional options.','LaTeX is a powerful markup language for writing complex mathematical equations and formulas.
		Jetpack combines the power of LaTeX and the simplicity of WordPress to give you the ultimate
		in math blogging platforms. Use $latex your latex code here$ or [latex]your latex code here[/latex]
		to include in your posts and comments. Enjoy all sorts of options and embrace your inner nerd.'=>'LaTeX is a powerful markup language for writing complex mathematical equations and formulas.
		Jetpack combines the power of LaTeX and the simplicity of WordPress to give you the ultimate
		in maths blogging platforms. Use $latex your latex code here$ or [latex]your latex code here[/latex]
		to include in your posts and comments. Enjoy all sorts of options and embrace your inner nerd.','You will receive instant notifications in your dashboard or your mobile device when somebody comments
		on any of your sites. Reply directly wherever you are to keep the conversation going.'=>'You will receive instant notifications in your dashboard or your mobile device when somebody comments
		on any of your sites. Reply directly wherever you are to keep the conversation going.','Automatically share and promote newly published posts to Facebook, Tumblr,
		and LinkedIn. You can add connections for yourself or for all users on your site.'=>'Automatically share and promote newly published posts to Facebook, Tumblr,
		and LinkedIn. You can add connections for yourself or for all users on your site.','Simple and concise statistics about your traffic. Jetpack Stats collects data on page views, likes, comments,
		locations, and top posts. View them in your dashboard or on WordPress.com.'=>'Simple and concise statistics about your traffic. Jetpack Stats collects data on page views, likes, comments,
		locations, and top posts. View them in your dashboard or on WordPress.com.','Easily and safely embed media from YouTube, Facebook, Flickr, Vimeo, Instagram,
		Google Maps, SlideShare, Vine, SoundCloud, and more. Just enter the appropriate shortcode directly into the
		editor and click “Publish.”'=>'Easily and safely embed media from YouTube, Facebook, Flickr, Vimeo, Instagram,
		Google Maps, SlideShare, Vine, SoundCloud, and more. Just enter the appropriate shortcode directly into the
		editor and click “Publish.”','Grab short and simple links to your posts and pages using the compact wp.me domain name. Perfect
		for use on Twitter, Facebook, and in text messages where every character counts.'=>'Grab short and simple links to your posts and pages using the compact wp.me domain name. Perfect
		for use on Twitter, Facebook, and in text messages where every character counts.','Enhance plain Gravatar images with information about a person (including a name,
		bio, pictures, and contact info) when they leave a comment on one of your posts.'=>'Enhance plain Gravatar images with information about a person (including a name,
		bio, pictures, and contact info) when they leave a comment on one of your posts.','We keep a daily or real-time backup of your site so that when mistakes or accidents occur, restoring your
		site to any location takes a matter of minutes. Your site’s files are regularly scanned for unauthorized or
		suspicious modifications that could compromise your security and data. In many cases, we can fix them
		automatically (and will notify you). When we can’t, we provide you with expert support.'=>'We keep a daily or real-time backup of your site so that when mistakes or accidents occur, restoring your
		site to any location takes a matter of minutes. Your site’s files are regularly scanned for unauthorised or
		suspicious modifications that could compromise your security and data. In many cases, we can fix them
		automatically (and will notify you). When we can’t, we provide you with expert support.','%1$s and %2$s'=>'%1$s and %2$s','The module %s failed to be activated.'=>'The module %s failed to be activated.' . "\0" . 'The modules %s failed to be activated.','The module %s was activated.'=>'The module %s was activated.' . "\0" . 'The modules %s were activated.','All modules activated.'=>'All modules activated.','The requested Jetpack module could not be deactivated.'=>'The requested Jetpack module could not be deactivated.','The requested Jetpack module was deactivated.'=>'The requested Jetpack module was deactivated.','The requested Jetpack module was already inactive.'=>'The requested Jetpack module was already inactive.','The requested Jetpack module could not be activated.'=>'The requested Jetpack module could not be activated.','The requested Jetpack module was activated.'=>'The requested Jetpack module was activated.','Feature Info'=>'Feature Info','VaultPress is active and will back up your site soon.'=>'VaultPress is active and will back up your site soon.','You need to register for VaultPress.'=>'You need to register for VaultPress.','Your site is verified with %1$s and %2$s.'=>'Your site is verified with %1$s and %2$s.','Your site is verified with %s.'=>'Your site is verified with %s.','Site not verified with any service.'=>'Site not verified with any service.','Invalid Akismet key. Please contact support.'=>'Invalid Akismet key. Please contact support.','Please activate Akismet.'=>'Please activate Akismet.','Please install Akismet.'=>'Please install Akismet.','The requested Jetpack module is not active.'=>'The requested Jetpack module is not active.','Unable to delete the Post by Email address. Please try again later.'=>'Unable to delete the Post by Email address. Please try again later.','Unable to regenerate the Post by Email address. Please try again later.'=>'Unable to regenerate the Post by Email address. Please try again later.','Unable to create the Post by Email address. Please try again later.'=>'Unable to create the Post by Email address. Please try again later.','Missing options.'=>'Missing options.','The requested Jetpack module is inactive.'=>'The requested Jetpack module is inactive.','The requested Jetpack module was not found.'=>'The requested Jetpack module was not found.','Plugin found.'=>'Plugin found.','Plugin %s is not installed.'=>'Plugin %s is not installed.','This site has no plugins.'=>'This site has no plugins.','Unable to list plugins.'=>'Unable to list plugins.','Could not check updates for plugins on this site.'=>'Could not check updates for plugins on this site.','All plugins are up-to-date. Keep up the good work!'=>'All plugins are up-to-date. Keep up the good work!','%s must be a string.'=>'%s must be a string.','%s must be a Twitter username.'=>'%s must be a Twitter username.','%s is not a registered custom sharing service.'=>'%s is not a registered custom sharing service.','%s must be a string prefixed with \'custom-\' and followed by a numeric ID.'=>'%s must be a string prefixed with \'custom-\' and followed by a numeric ID.','%s needs sharing name, url and icon.'=>'%s needs sharing name, URL, and icon.','%s must be an array with sharing name, url and icon.'=>'%s must be an array with sharing name, URL, and icon.','%1$s visible and hidden items must be a list of %2$s.'=>'%1$s visible and hidden items must be a list of %2$s.','Failed loading required dependency Sharing_Service.'=>'Failed loading required dependency Sharing_Service.','%s must be an array with visible and hidden items.'=>'%s must be an array with visible and hidden items.','Your site was successfully backed up %s ago.'=>'Your site was successfully backed up %s ago.','%s plugin needs updating.'=>'%s plugin needs updating.' . "\0" . '%s plugins need updating.','%1$s must be %2$s.'=>'%1$s must be %2$s.','%s must be an alphanumeric string.'=>'%s must be an alphanumeric string.','%s must be a list of valid modules'=>'%s must be a list of valid modules','Version.'=>'Version.','Do not track.'=>'Do not track.','Blog ID.'=>'Blog ID.','Pinterest Site Verification'=>'Pinterest Site Verification','Bing Webmaster Center'=>'Bing Webmaster Centre','Google Search Console'=>'Google Search Console','Delete custom sharing service.'=>'Delete custom sharing service.','Custom sharing services added by user.'=>'Custom sharing services added by user.','Views where buttons are shown'=>'Views where buttons are shown','Sharing Label'=>'Sharing Label','Button Style'=>'Button Style','Enabled Services and those hidden behind a button'=>'Enabled Services and those hidden behind a button','Disabled'=>'Disabled','Enabled'=>'Enabled','Regenerate Post by Email address'=>'Regenerate Post by Email address','Create Post by Email address'=>'Create Post by Email address','Send email notification when someone likes a post'=>'Send email notification when someone likes a post','Enable or disable Jetpack testimonial post type.'=>'Enable or disable Jetpack testimonial post type.','Enable or disable Jetpack portfolio post type.'=>'Enable or disable Jetpack portfolio post type.','Number of entries to show at most in Testimonial pages.'=>'Number of entries to show at most on Testimonial pages.','Number of entries to show at most in Portfolio pages.'=>'Number of entries to show at most on Portfolio pages.','Missing parameter "type".'=>'Missing parameter "type".','Invalid Parameter'=>'Invalid Parameter','Jetpack options reset.'=>'Jetpack options reset.','The ID of this site does not exist.'=>'The ID of this site does not exist.','Site data correctly received.'=>'Site data correctly received.','%s must be an array'=>'%s must be an array','%1$s must be one of %2$s'=>'%1$s must be one of %2$s','%s not recognized'=>'%s not recognised','%s must be a positive integer.'=>'%s must be a positive integer.','%s must be true, false, 0 or 1.'=>'%s must be true, false, 0 or 1.','Protect API key'=>'Protect API key','Delete Post by Email address'=>'Delete Post by Email address','Missing parameter "notice".'=>'Missing parameter "notice".','Invalid parameter "notice".'=>'Invalid parameter "notice".','You do not have the correct user permissions to perform this action.
			Please contact your site admin if you think this is a mistake.'=>'You do not have the correct user permissions to perform this action.
			Please contact your site admin if you think this is a mistake.','Turn on JavaScript to unlock Jetpack\'s full potential!'=>'Turn on JavaScript to unlock Jetpack\'s full potential!','You have JavaScript disabled'=>'You have JavaScript disabled','Dashboard'=>'Dashboard','Was not able to unlink the user. Please try again.'=>'Was not able to unlink the user. Please try again.','Unable to build the connect URL. Please reload the page and try again.'=>'Unable to build the connect URL. Please reload the page and try again.','Was not able to disconnect the site. Please try again.'=>'Was not able to disconnect the site. Please try again.','Big iPhone/iPad Update Now Available'=>'Big iPhone/iPad Update Now Available','The WordPress for Android App Gets a Big Facelift'=>'The WordPress for Android App Gets a Big Facelift','Copied!'=>'Copied!','Upgrade'=>'Upgrade','Automattic\'s Privacy Policy'=>'Automattic\'s Privacy Policy','WordPress.com Terms of Service'=>'WordPress.com Terms of Service','Loading'=>'Loading','Google now requires an API key to use their maps on your site. <a href="%s">See our documentation</a> for instructions on acquiring a key.'=>'Google now requires an API key to use their maps on your site. <a href="%s">See our documentation</a> for instructions on acquiring a key.','Google Maps API Key'=>'Google Maps API Key','Uploaded by %s'=>'Uploaded by %s','NounFormat:'=>'Format:','An error has been encountered.'=>'An error has been encountered.','The video has been imported as Attachment ID %d'=>'The video has been imported as Attachment ID %d','Invalid image URL'=>'Invalid image URL','We couldn\'t find your account. If you already have an account, make sure you have connected to WordPress.com.'=>'We couldn\'t find your account. If you already have an account, make sure you have connected to WordPress.com.','A WordPress.com account is required to access this site. Click the button below to sign in or create a free WordPress.com account.'=>'A WordPress.com account is required to access this site. Click the button below to sign in or create a free WordPress.com account.','You already have an account on this site. Please <a href="%1$s">sign in</a> with your username and password and then connect to WordPress.com.'=>'You already have an account on this site. Please <a href="%1$s">sign in</a> with your username and password and then connect to WordPress.com.','Must specify Twitter Timeline id or username.'=>'Must specify Twitter Timeline ID or username.','Portfolio Archive Featured Image'=>'Portfolio Archive Featured Image','Portfolio Archive Content'=>'Portfolio Archive Content','Portfolio Archive Title'=>'Portfolio Archive Title','No location or theme ID provided in the untappd-menu shortcode.'=>'No location or theme ID provided in the untappd-menu shortcode.','Log in with username and password'=>'Log in with username and password','Or'=>'Or','You can now save time spent logging in by connecting your WordPress.com account to %s.'=>'You can now save time spent logging in by connecting your WordPress.com account to %s.','Log in as <span>%s</span>'=>'Log in as <span>%s</span>','recipeDirections'=>'Directions','recipeIngredients'=>'Ingredients','recipePrint'=>'Print','recipeDifficulty'=>'Difficulty','recipeTime'=>'Time','recipeServings'=>'Servings','share toWhatsApp'=>'WhatsApp','WhatsApp'=>'WhatsApp','share toTelegram'=>'Telegram','Telegram'=>'Telegram','Check the box above to record each new set of posts loaded via Infinite Scroll as a page view in Google Analytics.'=>'Check the box above to record each new set of posts loaded via Infinite Scroll as a page view in Google Analytics.','Check to load posts as you scroll. Uncheck to show clickable button to load posts'=>'Check to load posts as you scroll. Uncheck to show clickable button to load posts','Infinite Scroll Behavior'=>'Infinite Scroll Behaviour','Testimonial Archive Content'=>'Testimonial Archive Content','Testimonial Archive Title'=>'Testimonial Archive Title','Checking'=>'Checking','For more help, try our <a href="%1$s">connection debugger</a> or <a href="%2$s" target="_blank">troubleshooting tips</a>.'=>'For more help, try our <a href="%1$s">connection debugger</a> or <a href="%2$s" target="_blank">troubleshooting tips</a>.','Jetpack will re-test for HTTPS support once a day, but you can click here to try again immediately: '=>'Jetpack will re-test for HTTPS support once a day, but you can click here to try again immediately: ','Try again'=>'Try again','Your site could not connect to WordPress.com via HTTPS. This could be due to any number of reasons, including faulty SSL certificates, misconfigured or missing SSL libraries, or network issues.'=>'Your site could not connect to WordPress.com via HTTPS. This could be due to any number of reasons, including faulty SSL certificates, misconfigured or missing SSL libraries, or network issues.','Outbound HTTPS not working'=>'Outbound HTTPS not working','Response was not OK: '=>'Response was not OK: ','WordPress reports no SSL support'=>'WordPress reports no SSL support','Manage Plugins'=>'Manage Plugins','Jetpack is not active on this site.'=>'Jetpack is not active on this site.','Video Width'=>'Video Width','pixels'=>'pixels','Start Video After'=>'Start Video After','seconds'=>'seconds','Loop video playback'=>'Loop video playback','Autoplay video on page load'=>'Autoplay video on page load','High definition on by default'=>'High definition on by default','Video ID'=>'Video ID','Use legacy Flash Player (not recommended)'=>'Use legacy Flash Player (not recommended)','Use only Open Source codecs (may degrade performance)'=>'Use only Open Source codecs (may degrade performance)','Link the video title to its URL on VideoPress.com'=>'Link the video title to its URL on VideoPress.com','VideoPress Shortcode'=>'VideoPress Shortcode','Invalid Video GUID!'=>'Invalid Video GUID!','Fill out my Wufoo form!'=>'Fill out my Wufoo form!','An error occurred while downloading blog information'=>'An error occurred while downloading blog information','Views'=>'Views','Order Top Posts &amp; Pages By:'=>'Order Top Posts &amp; Pages By:','Invalid site information returned from remote.'=>'Invalid site information returned from remote.','No posts data returned by remote.'=>'No posts data returned by remote.','Information about this blog is currently being retrieved.'=>'Information about this blog is currently being retrieved.','Cannot load blog information at this time.'=>'Cannot load blog information at this time.','Cannot load blog posts at this time.'=>'Cannot load blog posts at this time.','You must specify a valid blog URL!'=>'You must specify a valid blog URL!','An error occurred while downloading blog posts list'=>'An error occurred while downloading the blog posts list','Detailed information'=>'Detailed information','Social Menu'=>'Social Menu','Facebook Page Plugin'=>'Facebook Page Plugin','Invalid remote response.'=>'Invalid remote response.','An error occurred fetching the remote data.'=>'An error occurred fetching the remote data.','Use the Facebook Page Plugin to connect visitors to your Facebook Page'=>'Use the Facebook Page Plugin to connect visitors to your Facebook Page','XML Sitemap'=>'XML Sitemap','Module NameSitemaps'=>'Sitemaps','Module TagTraffic'=>'Traffic','If this solves the problem, something in your theme is probably broken – let the theme\'s author know.'=>'If this solves the problem, something in your theme is probably broken – let the theme\'s author know.','If your problem isn\'t known or caused by a plugin, try activating the default WordPress theme.'=>'If your problem isn\'t known or caused by a plugin, try activating the default WordPress theme.','If your problem isn\'t known or caused by a plugin, try activating %s (the default WordPress theme).'=>'If your problem isn\'t known or caused by a plugin, try activating %s (the default WordPress theme).','%s requires at least one selection.'=>'%s requires at least one selection.','You must specify an option_name'=>'You must specify an option_name','You must specify a whitelisted option_name'=>'You must specify a whitelisted option_name','You must specify an option_value'=>'You must specify an option_value','<span>Author:</span> <a href="%1$s">%2$s</a>'=>'<span>Author:</span> <a href="%1$s">%2$s</a>','Success!'=>'Success!','Comments are not allowed.'=>'Comments are not allowed.','Your IP (%1$s) has been flagged for potential security violations.'=>'Your IP address (%1$s) has been flagged for potential security violations.','%s username:'=>'%s username:','Theme'=>'Theme','Layout'=>'Layout','Testimonial list navigation'=>'Testimonial list navigation','Testimonials list'=>'Testimonials list','Filter Testimonials list'=>'Filter Testimonials list','Project tag list'=>'Project tag list','Project tag list navigation'=>'Project tag list navigation','Project type list'=>'Project type list','Menu items list'=>'Menu items list','Projects list'=>'Projects list','Project type list navigation'=>'Project type list navigation','Project list navigation'=>'Project list navigation','Filter projects list'=>'Filter projects list','Filter menu items list'=>'Filter menu items list','Menu item labels list'=>'Menu item labels list','Menu section list'=>'Menu section list','Menu item list navigation'=>'Menu item list navigation','Menu section list navigation'=>'Menu section list navigation','Menu item label list navigation'=>'Menu item label list navigation','Forms list navigation'=>'Forms list navigation','Checkbox with Multiple Items'=>'Checkbox with Multiple Items','Site successfully connected.'=>'Site successfully connected.','Activated'=>'Activated','Get started with Jetpack Multisite'=>'Get started with Jetpack Multisite','Get started managing your Multisite install of Jetpack by connecting.'=>'Get started managing your Multisite install of Jetpack by connecting.','Learn more'=>'Learn more','Jetpack Network Settings Updated!'=>'Jetpack Network Settings Updated!','Sub-site override'=>'Sub-site override','Automattic'=>'Automattic','https://jetpack.com'=>'https://jetpack.com','Jetpack is network-activated and notices cannot be dismissed.'=>'Jetpack is network-activated and notices cannot be dismissed.','Delete'=>'Delete','Left'=>'Left','Right'=>'Right','Title:'=>'Title:','Carousel'=>'Carousel','Center'=>'Centre','Category'=>'Category','placeholder: dropdown menu to select widget visibility; hide if or show if%s if:'=>'%s if:','Used in the "%s if:" translation for the widget visibility dropdownShow'=>'Show','Used in the "%s if:" translation for the widget visibility dropdownHide'=>'Hide','Used as the default option in a dropdown list-- Select --'=>'-- Select --','Noun, as in: "The author of this post is..."Author'=>'Author','NounUser'=>'User','Noun, as in: "The user role of that can access this widget is..."Role'=>'Role','Noun, as in: "This post has one tag."Tag'=>'Tag','Noun, as in: "This page is a date archive."Date'=>'Date','Example: The user is looking at a page, not a post.Page'=>'Page','Noun, as in: "This post has one taxonomy."Taxonomy'=>'Taxonomy','Widget Visibility: {Rule Major [Page]} is {Rule Minor [Search results]}is'=>'is','Shown between widget visibility conditions.or'=>'or','Show Faces'=>'Show Faces','Show profile photos in the plugin.'=>'Show profile photos in the plugin.','Show Page Posts.'=>'Show Page Posts.','Show Cover Photo'=>'Show Cover Photo','Images:'=>'Images:','Choose Images'=>'Choose Images','Link To:'=>'Link To:','Random Order:'=>'Random Order:','Style:'=>'Style:','Display a photo gallery or slideshow'=>'Display a photo gallery or slideshow','Tiles'=>'Tiles','Attachment Page'=>'Attachment Page','Media File'=>'Media File','Goodreads'=>'Goodreads','1: User Name, 2: Service Name (Facebook, Twitter, ...)%1$s on %2$s'=>'%1$s on %2$s','Visibility'=>'Visibility','Display your books from Goodreads'=>'Display your books from Goodreads','past participle: books I have readRead'=>'Read','Currently Reading'=>'Currently Reading','my list of books to readTo Read'=>'To Read','Goodreads numeric user ID <a href="%s" target="_blank">(instructions)</a>:'=>'Goodreads numeric user ID <a href="%s" target="_blank">(instructions)</a>:','Shelf:'=>'Shelf:','Gravatar Profile'=>'Gravatar Profile','Display a mini version of your Gravatar Profile'=>'Display a mini version of your Gravatar Profile','You need to select what to show in this <a href="%s">Gravatar Profile widget</a>.'=>'You need to select what to show in this <a href="%s">Gravatar Profile widget</a>.','View Full Profile &rarr;'=>'View Full Profile &rarr;','Error loading profile'=>'Error loading profile','Personal Links'=>'Personal Links','Verified Services'=>'Verified Services','Posts'=>'Posts','Posts & Comments'=>'Posts & Comments','Feed(s) to Display:'=>'Feed(s) to Display:','Text Link'=>'Text Link','Image Link'=>'Image Link','Text & Image Links'=>'Text & Image Links','Red'=>'Red','Orange'=>'Orange','Green'=>'Green','Blue'=>'Blue','Purple'=>'Purple','Pink'=>'Pink','Silver'=>'Silver','Image Color:'=>'Image Colour:','A simple widget that displays social media icons.'=>'A simple widget that displays social media icons.','Social'=>'Social','View %1$s&#8217;s profile on %2$s'=>'View %1$s&#8217;s profile on %2$s','Twitter Timeline'=>'Twitter Timeline','Display an official Twitter Embedded Timeline widget.'=>'Display an official Twitter Embedded Timeline widget.','My Tweets'=>'My Tweets','Follow me on Twitter'=>'Follow me on Twitter','%s (Jetpack)'=>'%s (Jetpack)','Invalid User ID, please verify and re-enter your Goodreads numeric user ID.'=>'Invalid User ID. Please verify and re-enter your Goodreads numeric user ID.','Image'=>'Image','Show Excerpts:'=>'Show Excerpts:','Show Featured Image:'=>'Show Featured Image:','Blog URL:'=>'Blog URL:','Large'=>'Large','Small'=>'Small','Custom'=>'Custom','Medium'=>'Medium','Recent Posts'=>'Recent Posts','Display as:'=>'Display as:','Open link in a new window/tab'=>'Open link in a new window/tab','You need to enter your numeric user ID for the <a href="%1$s">Goodreads Widget</a> to work correctly. <a href="%2$s" target="_blank">Full instructions</a>.'=>'You need to enter your numeric user ID for the <a href="%1$s">Goodreads Widget</a> to work correctly. <a href="%2$s" target="_blank">Full instructions</a>.','Open links in new window/tab:'=>'Open links in new window/tab:','Number of Posts to Display:'=>'Number of Posts to Display:','Enter a WordPress.com or Jetpack WordPress site URL.'=>'Enter a WordPress.com or Jetpack WordPress site URL.','Displays a list of recent posts from another WordPress.com or Jetpack-enabled blog.'=>'Displays a list of recent posts from another WordPress.com or Jetpack-enabled blog.','Display WordPress Posts'=>'Display WordPress Posts','Top Posts &amp; Pages by views are calculated from 24-48 hours of stats. They take a while to change.'=>'Top Posts &amp; Pages by views are calculated from 24-48 hours of stats. They take a while to change.','Image Grid'=>'Image Grid','Image List'=>'Image List','Text List'=>'Text List','Types of pages to display:'=>'Types of pages to display:','Maximum number of posts to show (no more than 10):'=>'Maximum number of posts to show (no more than 10):','Shows your most viewed posts and pages.'=>'Shows your most viewed posts and pages.','Top Posts &amp; Pages'=>'Top Posts &amp; Pages','Image Size:'=>'Image Size:','Image Settings:'=>'Image Settings:','RSS Links'=>'RSS Links','Links to your blog\'s RSS feeds'=>'Links to your blog\'s RSS feeds','Link URL (when the image is clicked):'=>'Link URL (when the image is clicked):','If empty, we will attempt to determine the image size.'=>'If empty, we will attempt to determine the image size.','Image Alignment:'=>'Image Alignment:','Caption:'=>'Caption:','Image title:'=>'Image title:','Alternate text:'=>'Alternate text:','Image URL:'=>'Image URL:','Display an image in your sidebar'=>'Display an image in your sidebar','What\'s a Gravatar?'=>'What\'s a Gravatar?','Edit Your Profile'=>'Edit Your Profile','Opens in new window'=>'Opens in new window','Links to services that you use across the web.'=>'Links to services that you use across the web.','Show Account Links'=>'Show Account Links','Links to your websites, blogs, or any other sites that help describe who you are.'=>'Links to your websites, blogs, or any other sites that help describe who you are.','Show Personal Links'=>'Show Personal Links','Custom Email Address'=>'Custom Email Address','Select a user or pick "custom" and enter a custom email address.'=>'Select a user or pick "custom" and enter a custom email address.','The widget only works with Facebook Pages.'=>'The widget only works with Facebook Pages.','Facebook Page URL'=>'Facebook Page URL','Hours:'=>'Hours:','Phone:'=>'Phone:','Show map'=>'Show map','Address:'=>'Address:','Lunch: 11am - 2pm 
Dinner: M-Th 5pm - 11pm, Fri-Sat:5pm - 1am'=>'Lunch: 11am - 2pm 
Dinner: M-Th 5pm - 11pm, Fri-Sat: 5pm - 1am','Example of a phone number1-202-555-1212'=>'1-202-555-1212','3999 Mission Boulevard,
San Diego CA 92109'=>'3999 Mission Boulevard,
San Diego CA 92109','Hours & Info'=>'Hours & Info','Display a map with your location, hours, and contact information.'=>'Display a map with your location, hours, and contact information.','Transparent background'=>'Transparent background','Layout options:'=>'Layout options:','Twitter username:'=>'Twitter username:','It looks like your Facebook URL is incorrectly configured. Please check it in your <a href="%1$s">widget settings</a>.'=>'It looks like your Facebook URL is incorrectly configured. Please check it in your <a href="%1$s">widget settings</a>.','Logo'=>'Logo','The settings for Featured Content have <a href="%s">moved to Appearance &rarr; Customize</a>.'=>'The settings for Featured Content have <a href="%s">moved to Appearance &rarr; Customise</a>.','%s Error'=>'%s Error','Stats'=>'Statistics','Submit'=>'Submit','Change whether your visitors can subscribe to your posts or comments or both.'=>'Change whether your visitors can subscribe to your posts or comments or both.','Chart stats by'=>'Chart stats by','Don&#8217;t send this to subscribers'=>'Don&#8217;t send this to subscribers','Follow Blog'=>'Follow Blog','Follow Comments'=>'Follow Comments','Jetpack Subscriptions Settings'=>'Jetpack Subscriptions Settings','Jetpack Subscriptions:'=>'Jetpack Subscriptions:','month'=>'month','Show a <em>\'follow blog\'</em> option in the comment form'=>'Show a <em>\'follow blog\'</em> option in the comment form','Show a <em>\'follow comments\'</em> option in the comment form'=>'Show a <em>\'follow comments\'</em> option in the comment form','Show top posts over'=>'Show top posts over','Show top search terms over'=>'Show top search terms over','Sorry, nothing to report.'=>'Sorry, nothing to report.','the past day'=>'the past day','the past month'=>'the past month','the past quarter'=>'the past quarter','the past week'=>'the past week','the past year'=>'the past year','Top Posts'=>'Top Posts','Top Searches'=>'Top Searches','We were unable to get your stats just now. Please reload this page to try again.'=>'We were unable to get your stats just now. Please reload this page to try again.','Shortcode'=>'Shortcode','Front page'=>'Front page','Posts page'=>'Posts page','Site Logo'=>'Site Logo','Change logo'=>'Change logo','Choose logo'=>'Choose logo','Add logo'=>'Add logo','Remove logo'=>'Remove logo','&mdash; Select &mdash;'=>'&mdash; Select &mdash;','Join %s other subscriber'=>'Join %s other subscriber.' . "\0" . 'Join %s other subscribers.','All taxonomy pages'=>'All taxonomy pages','Static page:'=>'Static page:','Post type:'=>'Post type:','Search results'=>'Search results','404 error page'=>'404 error page','Archive page'=>'Archive page','Yearly archives'=>'Yearly archives','Monthly archives'=>'Monthly archives','Daily archives'=>'Daily archives','All date archives'=>'All date archives','All tag pages'=>'All tag pages','All author pages'=>'All author pages','Logged Out'=>'Logged Out','Logged In'=>'Logged In','All category pages'=>'All category pages','Location of the Ogg video file.'=>'Location of the Ogg video file.','Ogg File URL'=>'Ogg File URL','Could not obtain a VideoPress upload token. Please try again later.'=>'Could not obtain a VideoPress upload token. Please try again later.','No data found for VideoPress identifier: <strong>%s</strong>.'=>'No data found for VideoPress identifier: <strong>%s</strong>.','Publisher limits playback of video embeds.'=>'Publisher limits playback of video embeds.','<strong>%s</strong> is not an allowed embed site.'=>'<strong>%s</strong> is not an allowed embed site.','The VideoPress plugin could not communicate with the VideoPress servers. This error is most likely caused by a misconfigured plugin. Please reinstall or upgrade.'=>'The VideoPress plugin could not communicate with the VideoPress servers. This error is most likely caused by a misconfigured plugin. Please reinstall or upgrade.','Loading video...'=>'Loading video...','Play as in playback or view a movieJavaScript required to play %s.'=>'JavaScript required to play %s.','this video'=>'this video','watch a video titleWatch: %s'=>'Watch: %s','Please verify your birthday.'=>'Please verify your birthday.','This video is intended for mature audiences.'=>'This video is intended for mature audiences.','Display all your gallery pictures in a cool mosaic.'=>'Display all your gallery pictures in a cool mosaic.','Tiled Columns'=>'Tiled Columns','Circles'=>'Circles','Square Tiles'=>'Square Tiles','Tiled Mosaic'=>'Tiled Mosaic','Display Header Text'=>'Display Header Text','No logo set'=>'No logo set','Set as logo'=>'Set as logo','Tag name'=>'Tag name','Featured Content'=>'Featured Content','Show total number of subscribers? (%s subscriber)'=>'Show total number of subscribers? (%s subscriber)' . "\0" . 'Show total number of subscribers? (%s subscribers)','Success Message Text:'=>'Success Message Text:','Subscribe Button:'=>'Subscribe Button:','Subscribe Placeholder:'=>'Subscribe Placeholder:','Optional text to display to your readers:'=>'Optional text to display to your readers:','Widget title:'=>'Widget title:','Subscribe'=>'Subscribe','Enter your email address to subscribe to this blog and receive notifications of new posts by email.'=>'Enter your email address to subscribe to this blog and receive notifications of new posts by email.','Subscribe to Blog via Email'=>'Subscribe to Blog via Email','Email Address:'=>'Email Address:','Blog Subscriptions'=>'Blog Subscriptions','Add an email signup form to allow people to subscribe to your blog.'=>'Add an email signup form to allow people to subscribe to your blog.','Notify me of new posts by email.'=>'Notify me of new posts by email.','Notify me of follow-up comments by email.'=>'Notify me of follow-up comments by email.','Howdy.

You recently followed one of my posts. This means you will receive an email when new comments are posted.

To activate, click confirm below. If you believe this is an error, ignore this message and we\'ll never bother you again.'=>'Howdy.

You recently followed one of my posts. This means you will receive an email when new comments are posted.

To activate, click confirm below. If you believe this is an error, ignore this message and we\'ll never bother you again.','week'=>'week','day'=>'day','Select the roles that will be able to view stats reports.'=>'Select the roles that will be able to view stats reports.','Count the page views of registered users who are logged in.'=>'Count the page views of registered users who are logged in.','Loading&hellip;'=>'Loading&hellip;','An unknown error has occurred. Please try again later.'=>'An unknown error has occurred. Please try again later.','VideoPress'=>'VideoPress','This video requires <a rel="nofollow noopener noreferrer" href="%s" target="_blank">Adobe Flash</a> for playback.'=>'This video requires <a rel="nofollow noopener noreferrer" href="%s" target="_blank">Adobe Flash</a> for playback.','You do not have sufficient <a rel="nofollow noopener noreferrer" href="%s" target="_blank">freedom levels</a> to view this video. Support free software and upgrade.'=>'You do not have sufficient <a rel="nofollow noopener noreferrer" href="%s" target="_blank">freedom levels</a> to view this video. Support free software and upgrade.','%1$s %2$s View'=>'%1$s %2$s View' . "\0" . '%1$s %2$s Views','Oops! There was an error when subscribing. Please try again.'=>'Oops! There was an error when subscribing. Please try again.','Views over 48 hours. Click for more Jetpack Stats.'=>'Views over 48 hours. Click for more Jetpack Stats.','Facebook'=>'Facebook','Pinterest'=>'Pinterest','Close'=>'Close','Slideshow'=>'Slideshow','Time'=>'Time',' (Opens in new window)'=>' (Opens in new window)','Share this:'=>'Share this:','Share'=>'Share','URL'=>'URL','LinkedIn'=>'LinkedIn','Tumblr'=>'Tumblr','Print'=>'Print','More'=>'More','Icon'=>'Icon','Log in with WordPress.com'=>'Log in with WordPress.com','Cannot deal with cookie redirects, as headers are already sent.'=>'Cannot deal with cookie redirects, as headers are already sent.','Match by Email'=>'Match by Email','Require Two-Step Authentication'=>'Require Two-Step Authentication','Tweets by @%s'=>'Tweets by @%s','This slideshow requires JavaScript.'=>'This slideshow requires JavaScript.','Click to view slideshow.'=>'Click to view slideshow.','Click to autoplay the presentation!'=>'Click to autoplay the presentation!','This slideshow could not be started. Try refreshing the page or viewing it in another browser.'=>'This slideshow could not be started. Try refreshing the page or viewing it in another browser.','Take Our Survey'=>'Take Our Survey','Your blog does not currently have any published posts.'=>'Your blog does not currently have any published posts.','An error occurred creating your new sharing service - please check you gave valid details.'=>'An error occurred creating your new sharing service - please check you gave valid details.','Create Share Button'=>'Create Share Button','Enter the URL of a 16x16px icon you want to use for this service.'=>'Enter the URL of a 16x16px icon you want to use for this service.','Icon URL'=>'Icon URL','You can add the following variables to your service sharing URL:'=>'You can add the following variables to your service sharing URL:','Sharing URL'=>'Sharing URL','Service name'=>'Service name','Sharing label'=>'Sharing label','Official buttons'=>'Official buttons','Text only'=>'Text only','Icon only'=>'Icon only','Icon + text'=>'Icon + text','Button style'=>'Button style','Sharing is off. Add services above to enable.'=>'Sharing is off. Add services above to enable.','Live Preview'=>'Live Preview','Services dragged here will be hidden behind a share button.'=>'Services dragged here will be hidden behind a share button.','Drag and drop available services here.'=>'Drag and drop available services here.','Services dragged here will appear individually.'=>'Services dragged here will appear individually.','Enabled Services'=>'Enabled Services','Please note that your services have been restricted because your site is private.'=>'Please note that your services have been restricted because your site is private.','Add a new service'=>'Add a new service','Drag and drop the services you\'d like to enable into the box below.'=>'Drag and drop the services you\'d like to enable into the box below.','Available Services'=>'Available Services','Add sharing buttons to your blog and allow your visitors to share posts with their friends.'=>'Add sharing buttons to your blog and allow your visitors to share posts with their friends.','Warning! Multibyte support missing!'=>'Warning! Multibyte support missing!','share toPinterest'=>'Pinterest','share toTumblr'=>'Tumblr','Share on Tumblr'=>'Share on Tumblr','Remove Service'=>'Remove Service','share toPress This'=>'Press This','Press This'=>'Press This','share toPrint'=>'Print','share toFacebook'=>'Facebook','share toLinkedIn'=>'LinkedIn','share toReddit'=>'Reddit','Reddit'=>'Reddit','share toEmail'=>'Email','as sharing sourceEmail'=>'Email','Disable CSS and JS'=>'Disable CSS and JS','Shared Post'=>'Shared Post','Unexpected response'=>'Unexpected response','Invalid JSON'=>'Invalid JSON','The response parameter is invalid or malformed'=>'The response parameter is invalid or malformed','The response parameter is missing'=>'The response parameter is missing','The secret parameter is invalid or malformed'=>'The secret parameter is invalid or malformed','The secret parameter is missing'=>'The secret parameter is missing','Similar post'=>'Similar post','in {category/tag name}In "%s"'=>'In "%s"','Untitled Post'=>'Untitled Post','Show related content after posts'=>'Show related content after posts','This plugin will work without it, but multibyte support is used <a href="%s" rel="noopener noreferrer" target="_blank">if available</a>. You may see minor problems with Tweets and other sharing services.'=>'This plugin will work without it, but multibyte support is used <a href="%s" rel="noopener noreferrer" target="_blank">if available</a>. You may see minor problems with Tweets and other sharing services.','Advanced. If this option is checked, you must include these files in your theme manually for the sharing links to work.'=>'Advanced. If this option is checked, you must include these files in your theme manually for the sharing links to work.','With %s comment'=>'With %s comment' . "\0" . 'With %s comments','Share on Facebook'=>'Share on Facebook','Title'=>'Title','Email Address'=>'Email Address','An invalid request was made. This normally means that something intercepted or corrupted the request from your server to the Jetpack Server. Try again and see if it works this time.'=>'An invalid request was made. This normally means that something intercepted or corrupted the request from your server to the Jetpack Server. Try again and see if it works this time.','Connect'=>'Connect','Disconnect'=>'Disconnect','Error code: %s'=>'Error code: %s','Not Connected'=>'Not Connected','Show'=>'Show','There was a problem connecting to %s to create an authorized connection. Please try again in a moment.'=>'There was a problem connecting to %s to create an authorised connection. Please try again in a moment.','We could not verify that your server is making an authorized request. Please try again, and make sure there is nothing interfering with requests from your server to the Jetpack Server.'=>'We could not verify that your server is making an authorised request. Please try again, and make sure there is nothing interfering with requests from your server to the Jetpack Server.','No user information was included in your request. Please make sure that your user account has connected to Jetpack. Connect your user account by going to the <a href="%s">Jetpack page</a> within wp-admin.'=>'No user information was included in your request. Please make sure that your user account has connected to Jetpack. Connect your user account by going to the <a href="%s">Jetpack page</a> within wp-admin.','Refresh connection with {social media service}Refresh connection with %s'=>'Refresh connection with %s','This connection is working correctly.'=>'This connection is working correctly.','Video on %s'=>'Video on %s','Last Modified'=>'Last Modified','Save'=>'Save','Plugins'=>'Plugins','Custom CSS'=>'Custom CSS','Related'=>'Related','Hide related content after posts'=>'Hide related content after posts','Preview:'=>'Preview:','Related posts'=>'Related posts','Custom Message:'=>'Custom Message:','That connection has been removed.'=>'That connection has been removed.','Something which should never happen, happened. Sorry about that. If you try again, maybe it will work.'=>'Something which should never happen, happened. Sorry about that. If you try again, maybe it will work.','There was an error contacting Jetpack servers.'=>'There was an error contacting Jetpack servers.','No API key'=>'No API key','Your API key is invalid'=>'Your API key is invalid','Login Blocked by Jetpack'=>'Login Blocked by Jetpack','No reply from Jetpack servers'=>'No reply from Jetpack servers','Error connecting to WordPress.com. Code: %1$s, %2$s'=>'Error connecting to WordPress.com. Code: %1$s, %2$s','Your main blog is not connected to WordPress.com. Please connect to get an API key.'=>'Your main blog is not connected to WordPress.com. Please connect to get an API key.','View Network Admin'=>'View Network Admin','Cannot use global flag on non-multisites'=>'Cannot use global flag on non-multisites','Expecting an array'=>'Expecting an array','Continue &rarr;'=>'Continue &rarr;','Your answer was incorrect, please try again.'=>'Your answer was incorrect, please try again.','One of your IP addresses was not valid.'=>'One of your IP addresses was not valid.','Link account with WordPress.com'=>'Link account with WordPress.com','If you don\'t have a WordPress.com account yet, you can sign up for free in just a few seconds.'=>'If you don\'t have a WordPress.com account yet, you can sign up for free in just a few seconds.','To use Post By Email, you need to link your %s account to your WordPress.com account.'=>'To use Post By Email, you need to link your %s account to your WordPress.com account.','Disable Post By Email'=>'Disable Post By Email','Regenerate Address'=>'Regenerate Address','More information'=>'More information','Enable Post By Email'=>'Enable Post By Email','Receive Monitor Email Notifications.'=>'Receive Monitor Email Notifications.','Tiled Galleries'=>'Tiled Galleries','Post by Email'=>'Post by Email','Related Posts'=>'Related Posts','With Carousel active, any standard WordPress galleries or single images you have embedded in posts or pages will
		launch a full-screen photo browsing experience with comments and EXIF metadata.'=>'With Carousel active, any standard WordPress galleries or single images you have embedded in posts or pages will
		launch a full-screen photo browsing experience with comments and EXIF metadata.','Prove your humanity'=>'Prove your humanity','Loading map&hellip;'=>'Loading map&hellip;','Site icon'=>'Site icon','Please solve this math problem to prove that you are not a bot. Once you solve it, you will need to log in again.'=>'Please solve this maths problem to prove that you are not a bot. Once you solve it, you will need to log in again.','There was a problem connecting with Jetpack Social. Please try again in a moment.'=>'There was a problem connecting with Jetpack Social. Please try again in a moment.','No blog_id was included in your request. Please try disconnecting Jetpack from WordPress.com and then reconnecting it. Once you have done that, try connecting Jetpack Social again.'=>'No blog_id was included in your request. Please try disconnecting Jetpack from WordPress.com and then reconnecting it. Once you have done that, try connecting Jetpack Social again.','To use Jetpack Social, you\'ll need to link your %s account to your WordPress.com account using the link below.'=>'To use Jetpack Social, you\'ll need to link your %s account to your WordPress.com account using the link below.','Only super admins can edit the global allow list'=>'Only super admins can edit the global allow list','Module NameBeautiful Math'=>'Beautiful Maths','Notifications'=>'Notifications','Module TagSite Stats'=>'Site Stats','Module TagRecommended'=>'Recommended','Module TagDevelopers'=>'Developers','Module TagAppearance'=>'Appearance','Module TagSocial'=>'Social','Module TagPhotos and Videos'=>'Photos and Videos','Module TagWriting'=>'Writing','Module TagOther'=>'Other','Module NameExtra Sidebar Widgets'=>'Extra Sidebar Widgets','Module NameWidget Visibility'=>'Widget Visibility','Module NameVideoPress'=>'VideoPress','Module NameTiled Galleries'=>'Tiled Galleries','Module NameWP.me Shortlinks'=>'WP.me Shortlinks','Module NameShortcode Embeds'=>'Shortcode Embeds','Module NameSharing'=>'Sharing','Module NameNotifications'=>'Notifications','Module NameMarkdown'=>'Markdown','Module NameLikes'=>'Likes','Module NameJSON API'=>'JSON API','Module NameInfinite Scroll'=>'Infinite Scroll','Module NameGravatar Hovercards'=>'Gravatar Hovercards','Module NameComments'=>'Comments','Module NameSecure Sign On'=>'Secure Sign On','Module NameCustom Content Types'=>'Custom Content Types','Module NamePost by Email'=>'Post by Email','Module NameRelated Posts'=>'Related Posts','Module NameSite Verification'=>'Site Verification','Save Changes'=>'Save Changes','Email me whenever'=>'Email me whenever','Loading...'=>'Loading...','No'=>'No','Customize'=>'Customise','Sharing'=>'Sharing','Sharing Settings'=>'Sharing Settings','%1$s at %2$s'=>'%1$s at %2$s','Gallery'=>'Gallery','Module NameCarousel'=>'Carousel','Featured Images'=>'Featured Images','Markdown content'=>'Markdown content','Use Markdown for comments.'=>'Use Markdown for comments.','Learn more about Markdown.'=>'Learn more about Markdown.','Use Markdown for posts and pages.'=>'Use Markdown for posts and pages.','Markdown'=>'Markdown','Like'=>'Like','Like this:'=>'Like this:','Sharing Buttons'=>'Sharing Buttons','Settings have been saved'=>'Settings have been saved','Front Page, Archive Pages, and Search Results'=>'Front Page, Archive Pages, and Search Results','Show buttons on'=>'Show buttons on','On for all comments'=>'On for all comments','Comment Likes are'=>'Comment Likes are','Don\'t show the Reblog button on posts'=>'Don\'t show the Reblog button on posts','Show the Reblog button on posts'=>'Show the Reblog button on posts','WordPress.com Reblog Button'=>'WordPress.com Reblog Button','Turned on per post'=>'Turned on per post','On for all posts'=>'On for all posts','WordPress.com Likes are'=>'WordPress.com Likes are','Someone likes one of my posts'=>'Someone likes one of my posts','Likes Notifications'=>'Likes Notifications','Show sharing buttons.'=>'Show sharing buttons.','Show likes.'=>'Show likes.','Likes'=>'Likes','Likes and Shares'=>'Likes and Shares','Use Google Analytics with Infinite Scroll'=>'Use Google Analytics with Infinite Scroll','Theme: %1$s.'=>'Theme: %1$s.','Proudly powered by WordPress'=>'Proudly powered by WordPress','Scroll back to top'=>'Scroll back to top','Older posts'=>'Older posts','We&rsquo;ve changed this option to a click-to-scroll version for you since you have footer widgets in Appearance &rarr; Widgets, or your theme uses click-to-scroll as the default behavior.'=>'We&rsquo;ve changed this option to a click-to-scroll version for you since you have footer widgets in Appearance &rarr; Widgets, or your theme uses click-to-scroll as the default behaviour.','To infinity and beyond'=>'To infinity and beyond','Put your mouse over your Gravatar to check out your profile.'=>'Put your mouse over your Gravatar to check out your profile.','View people\'s profiles when you mouse over their Gravatars'=>'View people\'s profiles when you mouse over their Gravatars','Gravatar Hovercards'=>'Gravatar Hovercards','Your Testimonial Archive currently has no entries. You can start creating them on your dashboard.'=>'Your Testimonial Archive currently has no entries. You can start creating them on your dashboard.','Testimonial Archive Featured Image'=>'Testimonial Archive Featured Image','Shows %s post on each load.'=>'Shows %s post on each load.' . "\0" . 'Shows %s posts on each load.','Search results for: %s'=>'Search results for: %s','Default'=>'Default','Description'=>'Description','None'=>'None','Order'=>'Order','Custom field deleted.'=>'Custom field deleted.','Custom field updated.'=>'Custom field updated.','M j, Y @ G:i'=>'M j, Y @ G:i','Portfolio'=>'Portfolio','Thumbnail'=>'Thumbnail','Add New'=>'Add New','Customer Name'=>'Customer Name','For example, spicy, favorite, etc. <br /> Separate Labels with commas'=>'For example, spicy, favourite, etc. <br /> Separate Labels with commas','Labels: <small>spicy, favorite, etc. <em>Separate Labels with commas</em></small>'=>'Labels: <small>spicy, favourite, etc. <em>Separate Labels with commas</em></small>','No Menu Items found in Trash'=>'No Menu Items found in Bin','No Projects found in Trash'=>'No Projects found in Bin','No Testimonials found in Trash'=>'No Testimonials found in Bin','Customize Testimonials Archive'=>'Customise Testimonials Archive','OK'=>'OK','Uncategorized'=>'Uncategorized','Price'=>'Price','Labels'=>'Labels','%1$d Food Menu Item'=>'%1$d Food Menu Item' . "\0" . '%1$d Food Menu Items','Cancel'=>'Cancel','New Testimonial'=>'New Testimonial','View Testimonial'=>'View Testimonial','Search Testimonials'=>'Search Testimonials','Add New Testimonial'=>'Add New Testimonial','Edit Testimonial'=>'Edit Testimonial','Testimonial updated.'=>'Testimonial updated.','Testimonial restored to revision from %s'=>'Testimonial restored to revision from %s','Testimonial published. <a href="%s">View testimonial</a>'=>'Testimonial published. <a href="%s">View testimonial</a>','Testimonial saved.'=>'Testimonial saved.','Testimonial submitted. <a target="_blank" href="%s">Preview testimonial</a>'=>'Testimonial submitted: <a target="_blank" href="%s">Preview testimonial</a>','Testimonial scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview testimonial</a>'=>'Testimonial scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview testimonial</a>','Testimonial draft updated. <a target="_blank" href="%s">Preview testimonial</a>'=>'Testimonial draft updated: <a target="_blank" href="%s">Preview testimonial</a>','Testimonial'=>'Testimonial','Testimonial updated. <a href="%s">View testimonial</a>'=>'Testimonial updated. <a href="%s">View testimonial</a>','Testimonials'=>'Testimonials','Add New Project'=>'Add New Project','Search Projects'=>'Search Projects','View Project'=>'View Project','Edit Project'=>'Edit Project','New Project'=>'New Project','Projects'=>'Projects','Project'=>'Project','edit'=>'edit','Edit Menu Item'=>'Edit Menu Item','Enter the customer\'s name here'=>'Enter the customer\'s name here','No Testimonials found'=>'No Testimonials found','All Testimonials'=>'All Testimonials','Customer Testimonials'=>'Customer Testimonials','Testimonial pages display at most %1$s testimonials'=>'Testimonial pages display at most %1$s testimonials','Enable Testimonials for this site.'=>'Enable Testimonials for this site.','Your theme supports Testimonials'=>'Your theme supports Testimonials','Your Portfolio Archive currently has no entries. You can start creating them on your dashboard.'=>'Your Portfolio Archive currently has no entries. You can start creating them on your dashboard.','Project item draft updated. <a target="_blank" href="%s">Preview project</a>'=>'Project item draft updated. <a target="_blank" href="%s">Preview project</a>','Project scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview project</a>'=>'Project scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview project</a>','Project submitted. <a target="_blank" href="%s">Preview project</a>'=>'Project submitted. <a target="_blank" href="%s">Preview project</a>','Project saved.'=>'Project saved.','Project published. <a href="%s">View project</a>'=>'Project published. <a href="%s">View project</a>','Project restored to revision from %s'=>'Project restored to revision from %s','Project updated.'=>'Project updated.','Project updated. <a href="%s">View item</a>'=>'Project updated. <a href="%s">View item</a>','No tags found.'=>'No tags found.','Choose from the most used tags'=>'Choose from the most used tags','Add or remove tags'=>'Add or remove tags','Separate tags with commas'=>'Separate tags with commas','Popular Project Tags'=>'Popular Project Tags','Search Project Tags'=>'Search Project Tags','New Project Tag Name'=>'New Project Tag Name','Add New Project Tag'=>'Add New Project Tag','Update Project Tag'=>'Update Project Tag','View Project Tag'=>'View Project Tag','Edit Project Tag'=>'Edit Project Tag','All Project Tags'=>'All Project Tags','Project Tag'=>'Project Tag','Project Tags'=>'Project Tags','Search Project Types'=>'Search Project Types','Parent Project Type:'=>'Parent Project Type:','Parent Project Type'=>'Parent Project Type','New Project Type Name'=>'New Project Type Name','Add New Project Type'=>'Add New Project Type','Update Project Type'=>'Update Project Type','View Project Type'=>'View Project Type','Edit Project Type'=>'Edit Project Type','All Project Types'=>'All Project Types','Project Type'=>'Project Type','Project Types'=>'Project Types','No Projects found'=>'No Projects found','All Projects'=>'All Projects','Portfolio pages display at most %1$s projects'=>'Portfolio pages display at most %1$s projects','Enable Portfolio Projects for this site.'=>'Enable Portfolio Projects for this site.','Your theme supports <strong>%s</strong>'=>'Your theme supports <strong>%s</strong>','Portfolio Projects'=>'Portfolio Projects','No Labels'=>'No Labels','Nova label separator, '=>', ','Add These New Menu Items'=>'Add These New Menu Items','New Row'=>'New Row','Add to section:'=>'Add to section:','Move menu section down'=>'Move menu section down','Move menu section up'=>'Move menu section up','Save New Order'=>'Save New Order','Menu Items re-ordered.'=>'Menu Items re-ordered.','Add Many Items'=>'Add Many Items','Enter the menu item\'s name here'=>'Enter the menu item\'s name here','Menu item draft updated. <a target="_blank" href="%s">Preview item</a>'=>'Menu item draft updated. <a target="_blank" href="%s">Preview item</a>','Menu item scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview item</a>'=>'Menu item scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview item</a>','Menu item submitted. <a target="_blank" href="%s">Preview item</a>'=>'Menu item submitted. <a target="_blank" href="%s">Preview item</a>','Menu item saved.'=>'Menu item saved.','Menu item published. <a href="%s">View item</a>'=>'Menu item published. <a href="%s">View item</a>','Menu item restored to revision from %s'=>'Menu item restored to revision from %s','Menu item updated.'=>'Menu item updated.','Menu item updated. <a href="%s">View item</a>'=>'Menu item updated. <a href="%s">View item</a>','No Menu Items found'=>'No Menu Items found','Search Menu Items'=>'Search Menu Items','View Menu Item'=>'View Menu Item','New Menu Item'=>'New Menu Item','Add Menu Item'=>'Add Menu Item','Add One Item'=>'Add One Item','Food Menus'=>'Food Menus','Menu Item'=>'Menu Item','Menu Items'=>'Menu Items','Items on your restaurant\'s menu'=>'Items on your restaurant\'s menu','New Menu Sections Name'=>'New Menu Sections Name','Add New Menu Section'=>'Add New Menu Section','Update Menu Section'=>'Update Menu Section','View Menu Section'=>'View Menu Section','Edit Menu Section'=>'Edit Menu Section','Parent Menu Section:'=>'Parent Menu Section:','Parent Menu Section'=>'Parent Menu Section','All Menu Sections'=>'All Menu Sections','Search Menu Sections'=>'Search Menu Sections','Menu Section'=>'Menu Section','Menu Sections'=>'Menu Sections','No Labels found'=>'No Labels found','Choose from the most used Labels'=>'Choose from the most used Labels','Add or remove Labels'=>'Add or remove Labels','New Menu Item Label Name'=>'New Menu Item Label Name','Add New Menu Item Label'=>'Add New Menu Item Label','Update Menu Item Label'=>'Update Menu Item Label','View Menu Item Label'=>'View Menu Item Label','Edit Menu Item Label'=>'Edit Menu Item Label','All Menu Item Labels'=>'All Menu Item Labels','Popular Labels'=>'Popular Labels','Search Menu Item Labels'=>'Search Menu Item Labels','Menu Item Label'=>'Menu Item Label','Menu Item Labels'=>'Menu Item Labels','CSS'=>'CSS','Use these settings to display different types of content on your site.'=>'Use these settings to display different types of content on your site.','Your Custom Content Types'=>'Your Custom Content Types','Show more'=>'Show more','Types:'=>'Types:','Use the <kbd>TAB</kbd> key on your keyboard to move between columns and the <kbd>ENTER</kbd> or <kbd>RETURN</kbd> key to save each row and move on to the next.'=>'Use the <kbd>TAB</kbd> key on your keyboard to move between columns and the <kbd>ENTER</kbd> or <kbd>RETURN</kbd> key to save each row and move on to the next.','No forms found in Trash.'=>'No forms found in the Bin.','Nonce verification failed.'=>'Nonce verification failed.','Date'=>'Date','Comments'=>'Comments','Download'=>'Download','Add'=>'Add','Yes'=>'Yes','Adjust your Comments form with a clever greeting and color-scheme.'=>'Adjust your Comments form with a clever greeting and colour scheme.','Background color'=>'Background colour','Color Scheme'=>'Colour Scheme','%1$s = blog name, %2$s = post title%1$s %2$s'=>'%1$s %2$s','%1$s = blog name%1$s Sidebar'=>'%1$s Sidebar','{$date_format} \\a\\t {$time_format}%1$s \\a\\t %2$s'=>'%1$s \\a\\t %2$s','locales%1$s/%2$s'=>'%1$s/%2$s','%s (Required)'=>'%s (Required)','Website'=>'Website','Message'=>'Message','Subject'=>'Subject','Options'=>'Options','Email'=>'Email','Contact Form'=>'Contact Form','Leave a Reply'=>'Leave a Reply','Leave a Reply to %s'=>'Leave a Reply to %s','Light'=>'Light','Dark'=>'Dark','(required)'=>'(required)','Label'=>'Label','Comment'=>'Comment','Cancel reply'=>'Cancel reply','Text'=>'Text','Enter your email address'=>'Enter your email address','Required?'=>'Required?','Textarea'=>'Textarea','Radio'=>'Radio','Drop down'=>'Drop down','Checkbox'=>'Checkbox','Click here'=>'Click here','Sent by an unverified visitor to your site.'=>'Sent by an unverified visitor to your site.','Sent by a verified %s user.'=>'Sent by a verified %s user.','Error!'=>'Error!','Feedback discarded.'=>'Feedback discarded.','An error occurred. Please try again later.'=>'An error occurred. Please try again later.','Spam <span class="count">(%s)</span>'=>'Spam <span class="count">(%s)</span>' . "\0" . 'Spam <span class="count">(%s)</span>','Add Contact Form'=>'Add Contact Form','Submitting Comment%s'=>'Submitting Comment%s','Invalid security token.'=>'Invalid security token.','Error: please enter a valid email address.'=>'Error: please enter a valid email address.','Error: please fill the required fields (name, email).'=>'Error: please fill the required fields (name, email).','Invalid request'=>'Invalid request','A few catchy words to motivate your readers to comment'=>'A few catchy words to motivate your readers to comment','Greeting Text'=>'Greeting Text','Transparent'=>'Transparent','Display images in full-size carousel slideshow.'=>'Display images in full-size carousel slideshow.','White'=>'White','Black'=>'Black','Metadata'=>'Metadata','Enable carousel'=>'Enable carousel','Image Gallery Carousel'=>'Image Gallery Carousel','Please provide a valid email address.'=>'Please provide a valid email address.','Please provide an email address.'=>'Please provide an email address.','Please provide your name.'=>'Please provide your name.','Sorry, but we could not authenticate your request.'=>'Sorry, but we could not authenticate your request.','Comments on this post are closed.'=>'Comments on this post are closed.','No comment text was submitted.'=>'No comment text was submitted.','Missing target post ID.'=>'Missing target post ID.','Missing target blog ID.'=>'Missing target blog ID.','Missing attachment ID.'=>'Missing attachment ID.','You must be <a href="#" class="jp-carousel-comment-login">logged in</a> to post a comment.'=>'You must be <a href="#" class="jp-carousel-comment-login">logged in</a> to post a comment.','Commenting as %s'=>'Commenting as %s','Focal Length'=>'Focal Length','Shutter Speed'=>'Shutter Speed','Aperture'=>'Aperture','Camera'=>'Camera','Your comment is in moderation.'=>'Your comment is in moderation.','Your comment was approved.'=>'Your comment was approved.','Sorry, but there was an error posting your comment. Please try again later.'=>'Sorry, but there was an error posting your comment. Please try again later.','Please provide your name to comment.'=>'Please provide your name to comment.','Please provide an email address to comment.'=>'Please provide an email address to comment.','Please be sure to submit some text with your comment.'=>'Please be sure to submit some text with your comment.','View full size <span class="photo-size">%1$s<span class="photo-size-times">&times;</span>%2$s</span>'=>'View full size <span class="photo-size">%1$s<span class="photo-size-times">&times;</span>%2$s</span>','Loading Comments...'=>'Loading Comments...','Write a Comment...'=>'Write a Comment...','Post Comment'=>'Post Comment','Jetpack\'s Carousel has been disabled, because another plugin or your theme is overriding the [gallery] shortcode.'=>'Jetpack\'s Carousel has been disabled, because another plugin or your theme is overriding the [gallery] shortcode.','Show photo metadata (<a href="https://en.wikipedia.org/wiki/Exchangeable_image_file_format" target="_blank">Exif</a>) in carousel, when available.'=>'Show photo metadata (<a href="https://en.wikipedia.org/wiki/Exchangeable_image_file_format" target="_blank">Exif</a>) in carousel, when available.','%s requires a valid email address.'=>'%s requires a valid email address.','IP address'=>'IP address','Type'=>'Type','This user is not authorized to %s on this blog.'=>'This user is not authorised to %s on this blog.','This user is not authorized to manage plugins network wide.'=>'This user is not authorised to manage plugins network wide.','Album'=>'Album','No themes found.'=>'No themes found.','Home'=>'Home','(no title)'=>'(no title)','There was an error while getting the update data for this site.'=>'There was an error while getting the update data for this site.','There was an error updating your theme'=>'There was an error updating your theme','The theme is already installed'=>'The theme is already installed','There was an error installing your theme'=>'There was an error installing your theme','Limit must be greater than or equal to 0.'=>'Limit must be greater than or equal to 0.','Offset must be greater than or equal to 0.'=>'Offset must be greater than or equal to 0.','You are required to specify a theme to update.'=>'You are required to specify a theme to update.','You are not allowed to switch to this theme'=>'You are not allowed to switch to this theme','The specified theme was not found.'=>'The specified theme was not found.','Theme is empty.'=>'Theme is empty.','You are required to specify a theme to switch to.'=>'You are required to specify a theme to switch to.','There was an error updating your plugin'=>'There was an error updating your plugin','No update needed'=>'No update needed','Plugin deactivated.'=>'Plugin deactivated.','There was an error deactivating your plugin'=>'There was an error deactivating your plugin','The Plugin is already deactivated.'=>'The Plugin is already deactivated.','Plugin activated.'=>'Plugin activated.','Plugin can only be Network Activated'=>'Plugin can only be Network Activated','The Plugin is already active.'=>'The Plugin is already active.','The plugin is already installed'=>'The plugin is already installed','An unknown error occurred during installation'=>'An unknown error occurred during installation','There was an error installing your plugin'=>'There was an error installing your plugin','You are required to specify a plugin to activate.'=>'You are required to specify a plugin to activate.','No plugins found.'=>'No plugins found.','You are required to specify a plugin.'=>'You are required to specify a plugin.','There was an error while deactivating the module.'=>'There was an error while deactivating the module.','The Jetpack Module is already deactivated.'=>'The Jetpack Module is already deactivated.','There was an error while activating the module.'=>'There was an error while activating the module.','The Jetpack Module is already activated.'=>'The Jetpack Module is already activated.','Module not found: `%s`.'=>'Module not found: `%s`.','You are required to specify a module.'=>'You are required to specify a module.','Full management mode is off for this site.'=>'Full management mode is off for this site.','You must specify a valid action'=>'You must specify a valid action','You are required to specify a capability to check.'=>'You are required to specify a capability to check.','Artist'=>'Artist','Comment cache problem?'=>'Comment cache problem?','This post is password protected.'=>'This post is password protected.','Unknown post type requested.'=>'Unknown post type requested.','An active access token must be used to retrieve post counts.'=>'An active access token must be used to retrieve post counts.','Autosave encountered an unexpected error'=>'Autosave encountered an unexpected error','Thumbnail Grid'=>'Thumbnail Grid','{#} Blocked malicious login attempts -- number is on a prior line, text is a caption.Blocked malicious login attempts'=>'Blocked malicious login attempts','You must connect your Jetpack plugin to WordPress.com to use this feature.'=>'You must connect your Jetpack plugin to WordPress.com to use this feature.','The Client ID/WP.com Blog ID of this site'=>'The Client ID/WP.com Blog ID of this site','Jetpack Plugin Version'=>'Jetpack Plugin Version','The number of sites of the connected WP.com user'=>'The number of sites of the connected WP.com user','The WP.com user email of the connected user'=>'The WP.com user email of the connected user','The WP.com username of the connected user'=>'The WP.com username of the connected user','The WP.com user ID of the connected user'=>'The WP.com user ID of the connected user','Error Details: Jetpack ID begins with a numeral. Do not publicly post this error message! %s'=>'Error Details: Jetpack ID begins with a numeral. Do not publicly post this error message! %s','Error Details: Jetpack ID is not a scalar. Do not publicly post this error message! %s'=>'Error Details: Jetpack ID is not a scalar. Do not publicly post this error message! %s','Error Details: Jetpack ID is empty. Do not publicly post this error message! %s'=>'Error Details: Jetpack ID is empty. Do not publicly post this error message! %s','%l = list of Jetpack module/feature namesDeactivate %l'=>'Deactivate %l','%1$s = deactivation URL, %2$s = "Deactivate {list of Jetpack module/feature names}If your site is not publicly accessible, consider <a href="%1$s" title="%2$s">deactivating this feature</a>.'=>'If your site is not publicly accessible, consider <a href="%1$s" title="%2$s">deactivating this feature</a>.' . "\0" . 'If your site is not publicly accessible, consider <a href="%1$s" title="%2$s">deactivating these features</a>.','%l = list of Jetpack module/feature namesLike your site\'s RSS feeds, %l allows access to your posts and other content to third parties.'=>'Like your site\'s RSS feeds, %l allows access to your posts and other content to third parties.' . "\0" . 'Like your site\'s RSS feeds, %l allow access to your posts and other content to third parties.','Is this site private?'=>'Is this site private?','The old version has been deactivated and can be removed from your site.'=>'The old version has been deactivated and can be removed from your site.' . "\0" . 'The old versions have been deactivated and can be removed from your site.','Jetpack contains the most recent version of the old %l plugin.'=>'Jetpack contains the most recent version of the old %l plugin.' . "\0" . 'Jetpack contains the most recent versions of the old %l plugins.','Manage has been activated for you!'=>'Manage has been activated for you!','You are all set! Your site can now be managed from <a href="%s" target="_blank">wordpress.com/sites</a>.'=>'You are all set! Your site can now be managed from <a href="%s" target="_blank">wordpress.com/sites</a>.','Connect to WordPress.com'=>'Connect to WordPress.com','Jetpack Support'=>'Jetpack Support','Jetpack contains the most recent version of the old &#8220;%1$s&#8221; plugin.'=>'Jetpack contains the most recent version of the old &#8220;%1$s&#8221; plugin.','Second param must be numeric or empty'=>'Second param must be numeric or empty','First param must be string or empty'=>'First param must be string or empty','Jetpack requires WordPress version %s or later.'=>'Jetpack requires WordPress version %s or later.','You are currently running a development version of Jetpack. <a href="%s" target="_blank">Submit your feedback</a>'=>'You are currently running a development version of Jetpack. <a href="%s" target="_blank">Submit your feedback</a>','The Twitter username of the owner of this site\'s domain.'=>'The Twitter username of the owner of this site\'s domain.','Twitter Site Tag'=>'Twitter Site Tag','Post by %s.'=>'Post by %s.','Anti-spam can help to keep your blog safe from spam!'=>'Anti-spam can help to keep your blog safe from spam!','%s wants to access your site’s data. Log in to authorize that access.'=>'%s wants to access your site’s data. Log in to authorise that access.','The authorization process expired. Please go back and try again.'=>'The authorisation process expired. Please go back and try again.','Someone may be trying to trick you into giving them access to your site. Or it could be you just encountered a bug :).  Either way, please close this window.'=>'Someone may be trying to trick you into giving them access to your site. Or it could be you just encountered a bug :). Either way, please close this window.','Edit'=>'Edit','Name'=>'Name','You do not have sufficient permissions to access this page.'=>'You do not have sufficient permissions to access this page.','Search'=>'Search','Settings'=>'Settings','Activate'=>'Activate','Support'=>'Support','Feedback'=>'Feedback','Inactive'=>'Inactive','Jetpack'=>'Jetpack','%s has been activated.'=>'%s has been activated.','%s has been deactivated.'=>'%s has been deactivated.','%s is not a valid command.'=>'%s is not a valid command.','%s is not a valid module.'=>'%s is not a valid module.','%s option reset'=>'%s option reset','Learn More'=>'Learn More','Value'=>'Value','Site Name'=>'Site Name','Connected'=>'Connected','All'=>'All','Deactivate'=>'Deactivate','Configure'=>'Configure','Popular'=>'Popular','Active'=>'Active','Video post.'=>'Video post.','Video post by %s.'=>'Video post by %s.','Sites'=>'Sites','Visit the post for more.'=>'Visit the post for more.','Jetpack Sites'=>'Jetpack Sites','Path'=>'Path','No Modules Found'=>'No Modules Found','The primary connection is owned by <strong>%s</strong>\'s WordPress.com account.'=>'The primary connection is owned by <strong>%s</strong>\'s WordPress.com account.','If it\'s not by itself, a theme or plugin is displaying extra characters. Try steps 2 and 3.'=>'If it\'s not by itself, a theme or plugin is displaying extra characters. Try steps 2 and 3.','A theme conflict.'=>'A theme conflict.','Find out by disabling all plugins except Jetpack. If the problem persists, it\'s not a plugin issue. If the problem is solved, turn your plugins on one by one until the problem pops up again – there\'s the culprit! Let us know, and we\'ll try to help.'=>'Find out by disabling all plugins except Jetpack. If the problem persists, it\'s not a plugin issue. If the problem is solved, turn your plugins on one by one until the problem pops up again – there\'s the culprit! Let us know, and we\'ll try to help.','An incompatible plugin.'=>'An incompatible plugin.','A known issue.'=>'A known issue.','It may be caused by one of these issues, which you can diagnose yourself:'=>'It may be caused by one of these issues, which you can diagnose yourself:','Trouble with Jetpack?'=>'Trouble with Jetpack?','Your Jetpack setup looks a-okay!'=>'Your Jetpack setup looks a-okay!','Testing your site\'s compatibility with Jetpack...'=>'Testing your site\'s compatibility with Jetpack...','Domain `%1$s` just failed is_usable_domain check as it is a subdomain of WordPress.com.'=>'Domain `%1$s` just failed is_usable_domain check as it is a subdomain of WordPress.com.','Domain `%1$s` just failed is_usable_domain check as it uses an invalid top level domain.'=>'Domain `%1$s` just failed is_usable_domain check as it uses an invalid top level domain.','Domain `%1$s` just failed is_usable_domain check as it is in the forbidden array.'=>'Domain `%1$s` just failed is_usable_domain check as it is in the forbidden array.','Domain `%1$s` just failed is_usable_domain check as it is empty.'=>'Domain `%1$s` just failed is_usable_domain check as it is empty.','Error Details: %s'=>'Error Details: %s','You need to register your Jetpack before connecting it.'=>'You need to register your Jetpack before connecting it.','An administrator for this blog must set up the Jetpack connection.'=>'An administrator for this blog must set up the Jetpack connection.','Action cancelled. Have a question?'=>'Action cancelled. Have a question?','\'wp jetpack options\' is a command - do not translate.Type \'wp jetpack options\' for more info.'=>'Type \'wp jetpack options\' for more info.','\'get\', \'delete\', and \'update\' are commands - do not translate.Above are your options. You may \'get\', \'delete\', and \'update\' them.'=>'Above are your options. You may \'get\', \'delete\', and \'update\' them.','the value that they want to update the option tovalue'=>'value','a variable command that a user can write, provided in the printed instructionsoption'=>'option','Option'=>'Option','Sorry, no updating arrays at this time'=>'Sorry, no updating arrays at this time','Deleted option: %s'=>'Deleted option: %s','No command found.'=>'No command found.','All modules deactivated!'=>'All modules deactivated!','All modules activated!'=>'All modules activated!','Please specify a valid module.'=>'Please specify a valid module.','Modules reset to default.'=>'Modules reset to default.','Resetting default modules...
'=>'Resetting default modules...
','Resetting the jetpack options stored in wp_options...
'=>'Resetting the jetpack options stored in wp_options...
','Please specify if you would like to disconnect a blog or user.'=>'Please specify if you would like to disconnect a blog or user.','Please specify a user by either ID, username, or email.'=>'Please specify a user by either ID, username, or email.','Please specify a valid user.'=>'Please specify a valid user.','"wp jetpack status full" is a command - do not translateView full status with \'wp jetpack status full\''=>'View full status with \'wp jetpack status full\'','Additional data: '=>'Additional data: ','The WordPress.com blog_id is %d'=>'The WordPress.com blog_id is %d','The Jetpack Version is %s'=>'The Jetpack Version is %s','Jetpack is currently connected to WordPress.com'=>'Jetpack is currently connected to WordPress.com','Jetpack is not currently connected to WordPress.com'=>'Jetpack is not currently connected to WordPress.com','Newest'=>'Newest','Alphabetical'=>'Alphabetical','Jetpack Settings'=>'Jetpack Settings','My Jetpack'=>'My Jetpack','Test your site\'s compatibility with Jetpack.'=>'Test your site’s compatibility with Jetpack.','User has been successfully disconnected.'=>'User has been successfully disconnected.','Jetpack has been successfully disconnected for %s.'=>'Jetpack has been successfully disconnected for %s.','Updating an option from "this" to "that".Updated option: %1$s to "%2$s"'=>'Updated option: %1$s to "%2$s"','"wp jetpack module activate" is a command - do not translate%1$s is not active. You can activate it with "wp jetpack module activate %2$s"'=>'%1$s is not active. You can activate it with "wp jetpack module activate %2$s"','\'list\' and \'clear\' are commands and should not be translatedYou can also \'list\' or \'clear\' the always allowed list.'=>'You can also \'list\' or \'clear\' the always allowed list.','Please enter the IP address you want to always allow.'=>'Please enter the IP address you want to always allow.','Option not found or is empty. Use "list" to list option names'=>'Option not found or is empty. Use "list" to list option names','Instructions on how to add IP ranges - low_range/high_range should be translated.You can save a range of IPs {low_range}-{high_range}. No spaces allowed. (example: 1.1.1.1-2.2.2.2)'=>'You can save a range of IPs {low_range}-{high_range}. No spaces allowed. (example: 1.1.1.1-2.2.2.2)','Search modules…'=>'Search modules…','If you get a 404 message, contact your web host. Their security may block the XML-RPC file.'=>'If you get a 404 message, contact your web host. Their security may block the XML-RPC file.','Load your <a href="%s">XML-RPC file</a>. It should say “XML-RPC server accepts POST requests only.” on a line by itself.'=>'Load your <a href="%s">XML-RPC file</a>. It should say “XML-RPC server accepts POST requests only.” on a line by itself.','A problem with your XML-RPC file.'=>'A problem with your XML-RPC file.','Your home URL is set as `%1$s`, but your WordPress.com connection lists it as `%2$s`.'=>'Your home URL is set as `%1$s`, but your WordPress.com connection lists it as `%2$s`.','Privacy'=>'Privacy']];